from vemmio_client import addon_pb2 as _addon_pb2
from vemmio_client import admin_pb2 as _admin_pb2
from vemmio_client import battery_pb2 as _battery_pb2
from vemmio_client import ble_pb2 as _ble_pb2
from vemmio_client import carbon_monoxide_pb2 as _carbon_monoxide_pb2
from vemmio_client import color_pb2 as _color_pb2
from vemmio_client import configuration_pb2 as _configuration_pb2
from vemmio_client import devices_pb2 as _devices_pb2
from vemmio_client import firmware_pb2 as _firmware_pb2
from vemmio_client import gate_pb2 as _gate_pb2
from vemmio_client import gateway_pb2 as _gateway_pb2
from vemmio_client import info_pb2 as _info_pb2
from vemmio_client import level_pb2 as _level_pb2
from vemmio_client import lock_pb2 as _lock_pb2
from vemmio_client import messaging_pb2 as _messaging_pb2
from vemmio_client import meter_pb2 as _meter_pb2
from vemmio_client import remote_pb2 as _remote_pb2
from vemmio_client import roller_shutter_pb2 as _roller_shutter_pb2
from vemmio_client import siren_pb2 as _siren_pb2
from vemmio_client import status_pb2 as _status_pb2
from vemmio_client import structure_pb2 as _structure_pb2
from vemmio_client import switch_pb2 as _switch_pb2
from vemmio_client import temperature_pb2 as _temperature_pb2
from vemmio_client import thermostat_pb2 as _thermostat_pb2
from vemmio_client import ultraviolet_pb2 as _ultraviolet_pb2
from vemmio_client import wifi_pb2 as _wifi_pb2
from vemmio_client import zigbee_pb2 as _zigbee_pb2
from vemmio_client import zwave_pb2 as _zwave_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
REPLY_TYPE_ACK: CommandReplyType
REPLY_TYPE_DATA: CommandReplyType
REPLY_TYPE_EOF: CommandReplyType
REPLY_TYPE_ERROR: CommandReplyType
REPLY_TYPE_UNSPECIFIED: CommandReplyType
REQUEST_OPTION_NOACK: CommandRequestOption
REQUEST_OPTION_NORESPONSE: CommandRequestOption
REQUEST_OPTION_UNSPECIFIED: CommandRequestOption
REQUEST_TYPE_DATA: CommandRequestType
REQUEST_TYPE_EOF: CommandRequestType
REQUEST_TYPE_UNSPECIFIED: CommandRequestType

class CommandReply(_message.Message):
    __slots__ = ["data", "error", "payload", "type"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    data: CommandReplyData
    error: CommandReplyError
    payload: bytes
    type: CommandReplyType
    def __init__(self, type: _Optional[_Union[CommandReplyType, str]] = ..., error: _Optional[_Union[CommandReplyError, _Mapping]] = ..., data: _Optional[_Union[CommandReplyData, _Mapping]] = ..., payload: _Optional[bytes] = ...) -> None: ...

class CommandReplyData(_message.Message):
    __slots__ = ["AddonAddThermostat", "AddonList", "BatteryGet", "CarbonMonoxideGet", "ColorSet", "ConfigurationGet", "ConfigurationList", "ConfigurationSet", "DevicesList", "DisableAdvertising", "EnableAdvertising", "FirmwareLatestVersion", "FirmwareUpdate", "FirmwareUpgrade", "FirmwareUpload", "FollowLogs", "GateClose", "GateCycle", "GateOpen", "GetStructure", "Info", "KeyDown", "KeyUp", "LevelDecrease", "LevelDown", "LevelGet", "LevelGetStep", "LevelIncrease", "LevelSet", "LevelUp", "LockSet", "MeterGet", "MeterReset", "ReadLogs", "Reboot", "Restart", "RollerShutterClose", "RollerShutterOpen", "RollerShutterSet", "SirenGetDefaultTone", "SirenGetTones", "SirenGetVolume", "SirenPlayDefaultTone", "SirenPlayTone", "SirenSetDefaultTone", "SirenSetVolume", "StartSupport", "StatusCheck", "StopSupport", "SwitchOff", "SwitchOn", "TemperatureGet", "ThermostatFanModeSet", "ThermostatModeSet", "ThermostatModeSupGet", "ThermostatSetpointSet", "UltravioletGet", "WalkNodes", "WiFiConnect", "WiFiQuery", "WiFiScan", "ZWaveAbort", "ZWaveAddEntry", "ZWaveExclude", "ZWaveHeal", "ZWaveHealthCheck", "ZWaveInclude", "ZWaveListEntries", "ZWaveNotificationItems", "ZWaveReadNode", "ZWaveReadNodes", "ZWaveRemoveEntry", "ZWaveRemoveFailed", "ZWaveReplaceFailed", "ZWaveReset", "ZWaveTest", "ZWaveUpdate", "ZWaveUpdateNode", "ZigbeeExclude", "ZigbeeGetNodes", "ZigbeeInclude"]
    ADDONADDTHERMOSTAT_FIELD_NUMBER: _ClassVar[int]
    ADDONLIST_FIELD_NUMBER: _ClassVar[int]
    AddonAddThermostat: _addon_pb2.AddonAddResponse
    AddonList: _addon_pb2.AddonListResponse
    BATTERYGET_FIELD_NUMBER: _ClassVar[int]
    BatteryGet: _battery_pb2.BatteryGetResponse
    CARBONMONOXIDEGET_FIELD_NUMBER: _ClassVar[int]
    COLORSET_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATIONGET_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATIONLIST_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATIONSET_FIELD_NUMBER: _ClassVar[int]
    CarbonMonoxideGet: _carbon_monoxide_pb2.CarbonMonoxideGetResponse
    ColorSet: _color_pb2.ColorResponse
    ConfigurationGet: _configuration_pb2.ConfigurationGetResponse
    ConfigurationList: _configuration_pb2.ConfigurationListResponse
    ConfigurationSet: _configuration_pb2.ConfigurationSetResponse
    DEVICESLIST_FIELD_NUMBER: _ClassVar[int]
    DISABLEADVERTISING_FIELD_NUMBER: _ClassVar[int]
    DevicesList: _devices_pb2.DevicesListResponse
    DisableAdvertising: _ble_pb2.AdvertisingResponse
    ENABLEADVERTISING_FIELD_NUMBER: _ClassVar[int]
    EnableAdvertising: _ble_pb2.AdvertisingResponse
    FIRMWARELATESTVERSION_FIELD_NUMBER: _ClassVar[int]
    FIRMWAREUPDATE_FIELD_NUMBER: _ClassVar[int]
    FIRMWAREUPGRADE_FIELD_NUMBER: _ClassVar[int]
    FIRMWAREUPLOAD_FIELD_NUMBER: _ClassVar[int]
    FOLLOWLOGS_FIELD_NUMBER: _ClassVar[int]
    FirmwareLatestVersion: _firmware_pb2.FirmwareLatestVersionResponse
    FirmwareUpdate: _firmware_pb2.FirmwareUpdateResponse
    FirmwareUpgrade: _firmware_pb2.FirmwareUpgradeAck
    FirmwareUpload: _firmware_pb2.FirmwareChunkAck
    FollowLogs: _admin_pb2.LogsChunk
    GATECLOSE_FIELD_NUMBER: _ClassVar[int]
    GATECYCLE_FIELD_NUMBER: _ClassVar[int]
    GATEOPEN_FIELD_NUMBER: _ClassVar[int]
    GETSTRUCTURE_FIELD_NUMBER: _ClassVar[int]
    GateClose: _gate_pb2.GateResponse
    GateCycle: _gate_pb2.GateResponse
    GateOpen: _gate_pb2.GateResponse
    GetStructure: _structure_pb2.StructureResponse
    INFO_FIELD_NUMBER: _ClassVar[int]
    Info: _info_pb2.InfoResponse
    KEYDOWN_FIELD_NUMBER: _ClassVar[int]
    KEYUP_FIELD_NUMBER: _ClassVar[int]
    KeyDown: _remote_pb2.RemoteResponse
    KeyUp: _remote_pb2.RemoteResponse
    LEVELDECREASE_FIELD_NUMBER: _ClassVar[int]
    LEVELDOWN_FIELD_NUMBER: _ClassVar[int]
    LEVELGETSTEP_FIELD_NUMBER: _ClassVar[int]
    LEVELGET_FIELD_NUMBER: _ClassVar[int]
    LEVELINCREASE_FIELD_NUMBER: _ClassVar[int]
    LEVELSET_FIELD_NUMBER: _ClassVar[int]
    LEVELUP_FIELD_NUMBER: _ClassVar[int]
    LOCKSET_FIELD_NUMBER: _ClassVar[int]
    LevelDecrease: _level_pb2.LevelResponse
    LevelDown: _level_pb2.LevelResponse
    LevelGet: _level_pb2.LevelGetResponse
    LevelGetStep: _level_pb2.LevelGetResponse
    LevelIncrease: _level_pb2.LevelResponse
    LevelSet: _level_pb2.LevelResponse
    LevelUp: _level_pb2.LevelResponse
    LockSet: _lock_pb2.LockResponse
    METERGET_FIELD_NUMBER: _ClassVar[int]
    METERRESET_FIELD_NUMBER: _ClassVar[int]
    MeterGet: _meter_pb2.MeterGetResponse
    MeterReset: _meter_pb2.MeterResetResponse
    READLOGS_FIELD_NUMBER: _ClassVar[int]
    REBOOT_FIELD_NUMBER: _ClassVar[int]
    RESTART_FIELD_NUMBER: _ClassVar[int]
    ROLLERSHUTTERCLOSE_FIELD_NUMBER: _ClassVar[int]
    ROLLERSHUTTEROPEN_FIELD_NUMBER: _ClassVar[int]
    ROLLERSHUTTERSET_FIELD_NUMBER: _ClassVar[int]
    ReadLogs: _admin_pb2.LogsChunk
    Reboot: _gateway_pb2.RebootResponse
    Restart: _gateway_pb2.RestartResponse
    RollerShutterClose: _roller_shutter_pb2.RollerShutterResponse
    RollerShutterOpen: _roller_shutter_pb2.RollerShutterResponse
    RollerShutterSet: _roller_shutter_pb2.RollerShutterResponse
    SIRENGETDEFAULTTONE_FIELD_NUMBER: _ClassVar[int]
    SIRENGETTONES_FIELD_NUMBER: _ClassVar[int]
    SIRENGETVOLUME_FIELD_NUMBER: _ClassVar[int]
    SIRENPLAYDEFAULTTONE_FIELD_NUMBER: _ClassVar[int]
    SIRENPLAYTONE_FIELD_NUMBER: _ClassVar[int]
    SIRENSETDEFAULTTONE_FIELD_NUMBER: _ClassVar[int]
    SIRENSETVOLUME_FIELD_NUMBER: _ClassVar[int]
    STARTSUPPORT_FIELD_NUMBER: _ClassVar[int]
    STATUSCHECK_FIELD_NUMBER: _ClassVar[int]
    STOPSUPPORT_FIELD_NUMBER: _ClassVar[int]
    SWITCHOFF_FIELD_NUMBER: _ClassVar[int]
    SWITCHON_FIELD_NUMBER: _ClassVar[int]
    SirenGetDefaultTone: _siren_pb2.SirenGetDefaultToneResponse
    SirenGetTones: _siren_pb2.SirenGetTonesResponse
    SirenGetVolume: _siren_pb2.SirenGetVolumeResponse
    SirenPlayDefaultTone: _siren_pb2.SirenPlayDefaultToneResponse
    SirenPlayTone: _siren_pb2.SirenPlayToneResponse
    SirenSetDefaultTone: _siren_pb2.SirenSetDefaultToneResponse
    SirenSetVolume: _siren_pb2.SirenSetVolumeResponse
    StartSupport: _gateway_pb2.SupportResponse
    StatusCheck: _status_pb2.StatusCheckResponse
    StopSupport: _gateway_pb2.SupportResponse
    SwitchOff: _switch_pb2.SwitchResponse
    SwitchOn: _switch_pb2.SwitchResponse
    TEMPERATUREGET_FIELD_NUMBER: _ClassVar[int]
    THERMOSTATFANMODESET_FIELD_NUMBER: _ClassVar[int]
    THERMOSTATMODESET_FIELD_NUMBER: _ClassVar[int]
    THERMOSTATMODESUPGET_FIELD_NUMBER: _ClassVar[int]
    THERMOSTATSETPOINTSET_FIELD_NUMBER: _ClassVar[int]
    TemperatureGet: _temperature_pb2.TemperatureGetResponse
    ThermostatFanModeSet: _thermostat_pb2.ThermostatResponse
    ThermostatModeSet: _thermostat_pb2.ThermostatResponse
    ThermostatModeSupGet: _thermostat_pb2.ThermostatModeSupGetResponse
    ThermostatSetpointSet: _thermostat_pb2.ThermostatResponse
    ULTRAVIOLETGET_FIELD_NUMBER: _ClassVar[int]
    UltravioletGet: _ultraviolet_pb2.UltravioletGetResponse
    WALKNODES_FIELD_NUMBER: _ClassVar[int]
    WIFICONNECT_FIELD_NUMBER: _ClassVar[int]
    WIFIQUERY_FIELD_NUMBER: _ClassVar[int]
    WIFISCAN_FIELD_NUMBER: _ClassVar[int]
    WalkNodes: _admin_pb2.WalkNodesResponse
    WiFiConnect: _wifi_pb2.WiFiConnectResponse
    WiFiQuery: _wifi_pb2.WiFiQueryResponse
    WiFiScan: _wifi_pb2.WiFiScanResponse
    ZIGBEEEXCLUDE_FIELD_NUMBER: _ClassVar[int]
    ZIGBEEGETNODES_FIELD_NUMBER: _ClassVar[int]
    ZIGBEEINCLUDE_FIELD_NUMBER: _ClassVar[int]
    ZWAVEABORT_FIELD_NUMBER: _ClassVar[int]
    ZWAVEADDENTRY_FIELD_NUMBER: _ClassVar[int]
    ZWAVEEXCLUDE_FIELD_NUMBER: _ClassVar[int]
    ZWAVEHEALTHCHECK_FIELD_NUMBER: _ClassVar[int]
    ZWAVEHEAL_FIELD_NUMBER: _ClassVar[int]
    ZWAVEINCLUDE_FIELD_NUMBER: _ClassVar[int]
    ZWAVELISTENTRIES_FIELD_NUMBER: _ClassVar[int]
    ZWAVENOTIFICATIONITEMS_FIELD_NUMBER: _ClassVar[int]
    ZWAVEREADNODES_FIELD_NUMBER: _ClassVar[int]
    ZWAVEREADNODE_FIELD_NUMBER: _ClassVar[int]
    ZWAVEREMOVEENTRY_FIELD_NUMBER: _ClassVar[int]
    ZWAVEREMOVEFAILED_FIELD_NUMBER: _ClassVar[int]
    ZWAVEREPLACEFAILED_FIELD_NUMBER: _ClassVar[int]
    ZWAVERESET_FIELD_NUMBER: _ClassVar[int]
    ZWAVETEST_FIELD_NUMBER: _ClassVar[int]
    ZWAVEUPDATENODE_FIELD_NUMBER: _ClassVar[int]
    ZWAVEUPDATE_FIELD_NUMBER: _ClassVar[int]
    ZWaveAbort: _zwave_pb2.ZWaveAbortResponse
    ZWaveAddEntry: _zwave_pb2.ZWaveAddEntryResponse
    ZWaveExclude: _zwave_pb2.ZWaveExcludeStatus
    ZWaveHeal: _zwave_pb2.ZWaveHealResponse
    ZWaveHealthCheck: _zwave_pb2.ZWaveHealthCheckStatus
    ZWaveInclude: _zwave_pb2.ZWaveIncludeStatus
    ZWaveListEntries: _zwave_pb2.ZWaveListEntriesResponse
    ZWaveNotificationItems: _zwave_pb2.ZWaveNotificationItemsResponse
    ZWaveReadNode: _zwave_pb2.ZWaveNodeResponse
    ZWaveReadNodes: _zwave_pb2.ZWaveNodesResponse
    ZWaveRemoveEntry: _zwave_pb2.ZWaveRemoveEntryResponse
    ZWaveRemoveFailed: _zwave_pb2.ZWaveRemoveFailedResponse
    ZWaveReplaceFailed: _zwave_pb2.ZWaveReplaceFailedResponse
    ZWaveReset: _zwave_pb2.ZWaveResetResponse
    ZWaveTest: _zwave_pb2.ZWaveTestResponse
    ZWaveUpdate: _zwave_pb2.ZWaveUpdateStatus
    ZWaveUpdateNode: _zwave_pb2.ZWaveUpdateNodeResponse
    ZigbeeExclude: _zigbee_pb2.ZigbeeExcludeResponse
    ZigbeeGetNodes: _zigbee_pb2.ZigbeeNodesResponse
    ZigbeeInclude: _zigbee_pb2.ZigbeeIncludeResponse
    def __init__(self, AddonList: _Optional[_Union[_addon_pb2.AddonListResponse, _Mapping]] = ..., AddonAddThermostat: _Optional[_Union[_addon_pb2.AddonAddResponse, _Mapping]] = ..., WalkNodes: _Optional[_Union[_admin_pb2.WalkNodesResponse, _Mapping]] = ..., ReadLogs: _Optional[_Union[_admin_pb2.LogsChunk, _Mapping]] = ..., FollowLogs: _Optional[_Union[_admin_pb2.LogsChunk, _Mapping]] = ..., BatteryGet: _Optional[_Union[_battery_pb2.BatteryGetResponse, _Mapping]] = ..., ColorSet: _Optional[_Union[_color_pb2.ColorResponse, _Mapping]] = ..., ConfigurationList: _Optional[_Union[_configuration_pb2.ConfigurationListResponse, _Mapping]] = ..., ConfigurationGet: _Optional[_Union[_configuration_pb2.ConfigurationGetResponse, _Mapping]] = ..., ConfigurationSet: _Optional[_Union[_configuration_pb2.ConfigurationSetResponse, _Mapping]] = ..., ThermostatModeSet: _Optional[_Union[_thermostat_pb2.ThermostatResponse, _Mapping]] = ..., ThermostatModeSupGet: _Optional[_Union[_thermostat_pb2.ThermostatModeSupGetResponse, _Mapping]] = ..., ThermostatSetpointSet: _Optional[_Union[_thermostat_pb2.ThermostatResponse, _Mapping]] = ..., ThermostatFanModeSet: _Optional[_Union[_thermostat_pb2.ThermostatResponse, _Mapping]] = ..., DevicesList: _Optional[_Union[_devices_pb2.DevicesListResponse, _Mapping]] = ..., FirmwareUpload: _Optional[_Union[_firmware_pb2.FirmwareChunkAck, _Mapping]] = ..., FirmwareUpgrade: _Optional[_Union[_firmware_pb2.FirmwareUpgradeAck, _Mapping]] = ..., FirmwareUpdate: _Optional[_Union[_firmware_pb2.FirmwareUpdateResponse, _Mapping]] = ..., FirmwareLatestVersion: _Optional[_Union[_firmware_pb2.FirmwareLatestVersionResponse, _Mapping]] = ..., Reboot: _Optional[_Union[_gateway_pb2.RebootResponse, _Mapping]] = ..., Restart: _Optional[_Union[_gateway_pb2.RestartResponse, _Mapping]] = ..., StartSupport: _Optional[_Union[_gateway_pb2.SupportResponse, _Mapping]] = ..., StopSupport: _Optional[_Union[_gateway_pb2.SupportResponse, _Mapping]] = ..., Info: _Optional[_Union[_info_pb2.InfoResponse, _Mapping]] = ..., LevelGet: _Optional[_Union[_level_pb2.LevelGetResponse, _Mapping]] = ..., LevelGetStep: _Optional[_Union[_level_pb2.LevelGetResponse, _Mapping]] = ..., LevelSet: _Optional[_Union[_level_pb2.LevelResponse, _Mapping]] = ..., LevelUp: _Optional[_Union[_level_pb2.LevelResponse, _Mapping]] = ..., LevelDown: _Optional[_Union[_level_pb2.LevelResponse, _Mapping]] = ..., LevelIncrease: _Optional[_Union[_level_pb2.LevelResponse, _Mapping]] = ..., LevelDecrease: _Optional[_Union[_level_pb2.LevelResponse, _Mapping]] = ..., LockSet: _Optional[_Union[_lock_pb2.LockResponse, _Mapping]] = ..., MeterGet: _Optional[_Union[_meter_pb2.MeterGetResponse, _Mapping]] = ..., MeterReset: _Optional[_Union[_meter_pb2.MeterResetResponse, _Mapping]] = ..., RollerShutterOpen: _Optional[_Union[_roller_shutter_pb2.RollerShutterResponse, _Mapping]] = ..., RollerShutterClose: _Optional[_Union[_roller_shutter_pb2.RollerShutterResponse, _Mapping]] = ..., RollerShutterSet: _Optional[_Union[_roller_shutter_pb2.RollerShutterResponse, _Mapping]] = ..., SirenGetTones: _Optional[_Union[_siren_pb2.SirenGetTonesResponse, _Mapping]] = ..., SirenPlayTone: _Optional[_Union[_siren_pb2.SirenPlayToneResponse, _Mapping]] = ..., SirenPlayDefaultTone: _Optional[_Union[_siren_pb2.SirenPlayDefaultToneResponse, _Mapping]] = ..., SirenGetDefaultTone: _Optional[_Union[_siren_pb2.SirenGetDefaultToneResponse, _Mapping]] = ..., SirenSetDefaultTone: _Optional[_Union[_siren_pb2.SirenSetDefaultToneResponse, _Mapping]] = ..., SirenGetVolume: _Optional[_Union[_siren_pb2.SirenGetVolumeResponse, _Mapping]] = ..., SirenSetVolume: _Optional[_Union[_siren_pb2.SirenSetVolumeResponse, _Mapping]] = ..., SwitchOn: _Optional[_Union[_switch_pb2.SwitchResponse, _Mapping]] = ..., SwitchOff: _Optional[_Union[_switch_pb2.SwitchResponse, _Mapping]] = ..., TemperatureGet: _Optional[_Union[_temperature_pb2.TemperatureGetResponse, _Mapping]] = ..., WiFiQuery: _Optional[_Union[_wifi_pb2.WiFiQueryResponse, _Mapping]] = ..., WiFiScan: _Optional[_Union[_wifi_pb2.WiFiScanResponse, _Mapping]] = ..., WiFiConnect: _Optional[_Union[_wifi_pb2.WiFiConnectResponse, _Mapping]] = ..., ZigbeeInclude: _Optional[_Union[_zigbee_pb2.ZigbeeIncludeResponse, _Mapping]] = ..., ZigbeeExclude: _Optional[_Union[_zigbee_pb2.ZigbeeExcludeResponse, _Mapping]] = ..., ZigbeeGetNodes: _Optional[_Union[_zigbee_pb2.ZigbeeNodesResponse, _Mapping]] = ..., ZWaveInclude: _Optional[_Union[_zwave_pb2.ZWaveIncludeStatus, _Mapping]] = ..., ZWaveExclude: _Optional[_Union[_zwave_pb2.ZWaveExcludeStatus, _Mapping]] = ..., ZWaveAbort: _Optional[_Union[_zwave_pb2.ZWaveAbortResponse, _Mapping]] = ..., ZWaveReadNodes: _Optional[_Union[_zwave_pb2.ZWaveNodesResponse, _Mapping]] = ..., ZWaveUpdate: _Optional[_Union[_zwave_pb2.ZWaveUpdateStatus, _Mapping]] = ..., ZWaveUpdateNode: _Optional[_Union[_zwave_pb2.ZWaveUpdateNodeResponse, _Mapping]] = ..., ZWaveReset: _Optional[_Union[_zwave_pb2.ZWaveResetResponse, _Mapping]] = ..., ZWaveListEntries: _Optional[_Union[_zwave_pb2.ZWaveListEntriesResponse, _Mapping]] = ..., ZWaveAddEntry: _Optional[_Union[_zwave_pb2.ZWaveAddEntryResponse, _Mapping]] = ..., ZWaveRemoveEntry: _Optional[_Union[_zwave_pb2.ZWaveRemoveEntryResponse, _Mapping]] = ..., ZWaveNotificationItems: _Optional[_Union[_zwave_pb2.ZWaveNotificationItemsResponse, _Mapping]] = ..., ZWaveTest: _Optional[_Union[_zwave_pb2.ZWaveTestResponse, _Mapping]] = ..., ZWaveHeal: _Optional[_Union[_zwave_pb2.ZWaveHealResponse, _Mapping]] = ..., ZWaveReplaceFailed: _Optional[_Union[_zwave_pb2.ZWaveReplaceFailedResponse, _Mapping]] = ..., ZWaveRemoveFailed: _Optional[_Union[_zwave_pb2.ZWaveRemoveFailedResponse, _Mapping]] = ..., ZWaveHealthCheck: _Optional[_Union[_zwave_pb2.ZWaveHealthCheckStatus, _Mapping]] = ..., ZWaveReadNode: _Optional[_Union[_zwave_pb2.ZWaveNodeResponse, _Mapping]] = ..., CarbonMonoxideGet: _Optional[_Union[_carbon_monoxide_pb2.CarbonMonoxideGetResponse, _Mapping]] = ..., EnableAdvertising: _Optional[_Union[_ble_pb2.AdvertisingResponse, _Mapping]] = ..., DisableAdvertising: _Optional[_Union[_ble_pb2.AdvertisingResponse, _Mapping]] = ..., UltravioletGet: _Optional[_Union[_ultraviolet_pb2.UltravioletGetResponse, _Mapping]] = ..., KeyUp: _Optional[_Union[_remote_pb2.RemoteResponse, _Mapping]] = ..., KeyDown: _Optional[_Union[_remote_pb2.RemoteResponse, _Mapping]] = ..., GateOpen: _Optional[_Union[_gate_pb2.GateResponse, _Mapping]] = ..., GateClose: _Optional[_Union[_gate_pb2.GateResponse, _Mapping]] = ..., GateCycle: _Optional[_Union[_gate_pb2.GateResponse, _Mapping]] = ..., StatusCheck: _Optional[_Union[_status_pb2.StatusCheckResponse, _Mapping]] = ..., GetStructure: _Optional[_Union[_structure_pb2.StructureResponse, _Mapping]] = ...) -> None: ...

class CommandReplyError(_message.Message):
    __slots__ = ["message"]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: str
    def __init__(self, message: _Optional[str] = ...) -> None: ...

class CommandRequest(_message.Message):
    __slots__ = ["data", "method", "options", "payload", "type"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    data: CommandRequestData
    method: str
    options: _containers.RepeatedScalarFieldContainer[CommandRequestOption]
    payload: bytes
    type: CommandRequestType
    def __init__(self, method: _Optional[str] = ..., type: _Optional[_Union[CommandRequestType, str]] = ..., data: _Optional[_Union[CommandRequestData, _Mapping]] = ..., payload: _Optional[bytes] = ..., options: _Optional[_Iterable[_Union[CommandRequestOption, str]]] = ...) -> None: ...

class CommandRequestData(_message.Message):
    __slots__ = ["AddonAddThermostat", "AddonList", "BatteryGet", "CarbonMonoxideGet", "ColorSet", "ConfigurationGet", "ConfigurationList", "ConfigurationSet", "DevicesList", "DisableAdvertising", "EnableAdvertising", "FirmwareLatestVersion", "FirmwareUpdate", "FirmwareUpgrade", "FirmwareUpload", "FollowLogs", "GateClose", "GateCycle", "GateOpen", "GetStructure", "Info", "KeyDown", "KeyUp", "LevelDecrease", "LevelDown", "LevelGet", "LevelGetStep", "LevelIncrease", "LevelSet", "LevelUp", "LockSet", "MeterGet", "MeterReset", "ReadLogs", "Reboot", "Restart", "RollerShutterClose", "RollerShutterOpen", "RollerShutterSet", "SirenGetDefaultTone", "SirenGetTones", "SirenGetVolume", "SirenPlayDefaultTone", "SirenPlayTone", "SirenSetDefaultTone", "SirenSetVolume", "StartSupport", "StatusCheck", "StopSupport", "SwitchOff", "SwitchOn", "TemperatureGet", "ThermostatFanModeSet", "ThermostatModeSet", "ThermostatModeSupGet", "ThermostatSetpointSet", "UltravioletGet", "WalkNodes", "WiFiConnect", "WiFiQuery", "WiFiScan", "ZWaveAbort", "ZWaveAddEntry", "ZWaveExclude", "ZWaveHeal", "ZWaveHealthCheck", "ZWaveInclude", "ZWaveListEntries", "ZWaveNotificationItems", "ZWaveReadNode", "ZWaveReadNodes", "ZWaveRemoveEntry", "ZWaveRemoveFailed", "ZWaveReplaceFailed", "ZWaveReset", "ZWaveTest", "ZWaveUpdate", "ZWaveUpdateNode", "ZigbeeExclude", "ZigbeeGetNodes", "ZigbeeInclude"]
    ADDONADDTHERMOSTAT_FIELD_NUMBER: _ClassVar[int]
    ADDONLIST_FIELD_NUMBER: _ClassVar[int]
    AddonAddThermostat: _addon_pb2.AddonAddThermostatRequest
    AddonList: _addon_pb2.AddonListRequest
    BATTERYGET_FIELD_NUMBER: _ClassVar[int]
    BatteryGet: _battery_pb2.BatteryGetRequest
    CARBONMONOXIDEGET_FIELD_NUMBER: _ClassVar[int]
    COLORSET_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATIONGET_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATIONLIST_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATIONSET_FIELD_NUMBER: _ClassVar[int]
    CarbonMonoxideGet: _carbon_monoxide_pb2.CarbonMonoxideGetRequest
    ColorSet: _color_pb2.ColorSetRequest
    ConfigurationGet: _configuration_pb2.ConfigurationGetRequest
    ConfigurationList: _configuration_pb2.ConfigurationListRequest
    ConfigurationSet: _configuration_pb2.ConfigurationSetRequest
    DEVICESLIST_FIELD_NUMBER: _ClassVar[int]
    DISABLEADVERTISING_FIELD_NUMBER: _ClassVar[int]
    DevicesList: _devices_pb2.DevicesListRequest
    DisableAdvertising: _ble_pb2.AdvertisingRequest
    ENABLEADVERTISING_FIELD_NUMBER: _ClassVar[int]
    EnableAdvertising: _ble_pb2.AdvertisingRequest
    FIRMWARELATESTVERSION_FIELD_NUMBER: _ClassVar[int]
    FIRMWAREUPDATE_FIELD_NUMBER: _ClassVar[int]
    FIRMWAREUPGRADE_FIELD_NUMBER: _ClassVar[int]
    FIRMWAREUPLOAD_FIELD_NUMBER: _ClassVar[int]
    FOLLOWLOGS_FIELD_NUMBER: _ClassVar[int]
    FirmwareLatestVersion: _firmware_pb2.FirmwareLatestVersionRequest
    FirmwareUpdate: _firmware_pb2.FirmwareUpdateRequest
    FirmwareUpgrade: _firmware_pb2.FirmwareUpgradeRequest
    FirmwareUpload: _firmware_pb2.FirmwareChunk
    FollowLogs: _admin_pb2.LogsRequest
    GATECLOSE_FIELD_NUMBER: _ClassVar[int]
    GATECYCLE_FIELD_NUMBER: _ClassVar[int]
    GATEOPEN_FIELD_NUMBER: _ClassVar[int]
    GETSTRUCTURE_FIELD_NUMBER: _ClassVar[int]
    GateClose: _gate_pb2.GateRequest
    GateCycle: _gate_pb2.GateRequest
    GateOpen: _gate_pb2.GateRequest
    GetStructure: _structure_pb2.StructureRequest
    INFO_FIELD_NUMBER: _ClassVar[int]
    Info: _info_pb2.InfoRequest
    KEYDOWN_FIELD_NUMBER: _ClassVar[int]
    KEYUP_FIELD_NUMBER: _ClassVar[int]
    KeyDown: _remote_pb2.RemoteRequest
    KeyUp: _remote_pb2.RemoteRequest
    LEVELDECREASE_FIELD_NUMBER: _ClassVar[int]
    LEVELDOWN_FIELD_NUMBER: _ClassVar[int]
    LEVELGETSTEP_FIELD_NUMBER: _ClassVar[int]
    LEVELGET_FIELD_NUMBER: _ClassVar[int]
    LEVELINCREASE_FIELD_NUMBER: _ClassVar[int]
    LEVELSET_FIELD_NUMBER: _ClassVar[int]
    LEVELUP_FIELD_NUMBER: _ClassVar[int]
    LOCKSET_FIELD_NUMBER: _ClassVar[int]
    LevelDecrease: _level_pb2.LevelStepRequest
    LevelDown: _level_pb2.LevelStepRequest
    LevelGet: _level_pb2.LevelRequest
    LevelGetStep: _level_pb2.LevelRequest
    LevelIncrease: _level_pb2.LevelStepRequest
    LevelSet: _level_pb2.LevelSetRequest
    LevelUp: _level_pb2.LevelStepRequest
    LockSet: _lock_pb2.LockSetRequest
    METERGET_FIELD_NUMBER: _ClassVar[int]
    METERRESET_FIELD_NUMBER: _ClassVar[int]
    MeterGet: _meter_pb2.MeterGetRequest
    MeterReset: _meter_pb2.MeterResetRequest
    READLOGS_FIELD_NUMBER: _ClassVar[int]
    REBOOT_FIELD_NUMBER: _ClassVar[int]
    RESTART_FIELD_NUMBER: _ClassVar[int]
    ROLLERSHUTTERCLOSE_FIELD_NUMBER: _ClassVar[int]
    ROLLERSHUTTEROPEN_FIELD_NUMBER: _ClassVar[int]
    ROLLERSHUTTERSET_FIELD_NUMBER: _ClassVar[int]
    ReadLogs: _admin_pb2.LogsRequest
    Reboot: _gateway_pb2.RebootRequest
    Restart: _gateway_pb2.RestartRequest
    RollerShutterClose: _roller_shutter_pb2.RollerShutterRequest
    RollerShutterOpen: _roller_shutter_pb2.RollerShutterRequest
    RollerShutterSet: _roller_shutter_pb2.RollerShutterSetRequest
    SIRENGETDEFAULTTONE_FIELD_NUMBER: _ClassVar[int]
    SIRENGETTONES_FIELD_NUMBER: _ClassVar[int]
    SIRENGETVOLUME_FIELD_NUMBER: _ClassVar[int]
    SIRENPLAYDEFAULTTONE_FIELD_NUMBER: _ClassVar[int]
    SIRENPLAYTONE_FIELD_NUMBER: _ClassVar[int]
    SIRENSETDEFAULTTONE_FIELD_NUMBER: _ClassVar[int]
    SIRENSETVOLUME_FIELD_NUMBER: _ClassVar[int]
    STARTSUPPORT_FIELD_NUMBER: _ClassVar[int]
    STATUSCHECK_FIELD_NUMBER: _ClassVar[int]
    STOPSUPPORT_FIELD_NUMBER: _ClassVar[int]
    SWITCHOFF_FIELD_NUMBER: _ClassVar[int]
    SWITCHON_FIELD_NUMBER: _ClassVar[int]
    SirenGetDefaultTone: _siren_pb2.SirenGetDefaultToneRequest
    SirenGetTones: _siren_pb2.SirenGetTonesRequest
    SirenGetVolume: _siren_pb2.SirenGetVolumeRequest
    SirenPlayDefaultTone: _siren_pb2.SirenPlayDefaultToneRequest
    SirenPlayTone: _siren_pb2.SirenPlayToneRequest
    SirenSetDefaultTone: _siren_pb2.SirenSetDefaultToneRequest
    SirenSetVolume: _siren_pb2.SirenSetVolumeRequest
    StartSupport: _gateway_pb2.SupportRequest
    StatusCheck: _status_pb2.StatusCheckRequest
    StopSupport: _gateway_pb2.SupportRequest
    SwitchOff: _switch_pb2.SwitchRequest
    SwitchOn: _switch_pb2.SwitchRequest
    TEMPERATUREGET_FIELD_NUMBER: _ClassVar[int]
    THERMOSTATFANMODESET_FIELD_NUMBER: _ClassVar[int]
    THERMOSTATMODESET_FIELD_NUMBER: _ClassVar[int]
    THERMOSTATMODESUPGET_FIELD_NUMBER: _ClassVar[int]
    THERMOSTATSETPOINTSET_FIELD_NUMBER: _ClassVar[int]
    TemperatureGet: _temperature_pb2.TemperatureGetRequest
    ThermostatFanModeSet: _thermostat_pb2.ThermostatFanModeSetRequest
    ThermostatModeSet: _thermostat_pb2.ThermostatModeSetRequest
    ThermostatModeSupGet: _thermostat_pb2.ThermostatModeSupGetRequest
    ThermostatSetpointSet: _thermostat_pb2.ThermostatSetpointSetRequest
    ULTRAVIOLETGET_FIELD_NUMBER: _ClassVar[int]
    UltravioletGet: _ultraviolet_pb2.UltravioletGetRequest
    WALKNODES_FIELD_NUMBER: _ClassVar[int]
    WIFICONNECT_FIELD_NUMBER: _ClassVar[int]
    WIFIQUERY_FIELD_NUMBER: _ClassVar[int]
    WIFISCAN_FIELD_NUMBER: _ClassVar[int]
    WalkNodes: _admin_pb2.WalkNodesRequest
    WiFiConnect: _wifi_pb2.WiFiConnectRequest
    WiFiQuery: _wifi_pb2.WiFiQueryRequest
    WiFiScan: _wifi_pb2.WiFiScanRequest
    ZIGBEEEXCLUDE_FIELD_NUMBER: _ClassVar[int]
    ZIGBEEGETNODES_FIELD_NUMBER: _ClassVar[int]
    ZIGBEEINCLUDE_FIELD_NUMBER: _ClassVar[int]
    ZWAVEABORT_FIELD_NUMBER: _ClassVar[int]
    ZWAVEADDENTRY_FIELD_NUMBER: _ClassVar[int]
    ZWAVEEXCLUDE_FIELD_NUMBER: _ClassVar[int]
    ZWAVEHEALTHCHECK_FIELD_NUMBER: _ClassVar[int]
    ZWAVEHEAL_FIELD_NUMBER: _ClassVar[int]
    ZWAVEINCLUDE_FIELD_NUMBER: _ClassVar[int]
    ZWAVELISTENTRIES_FIELD_NUMBER: _ClassVar[int]
    ZWAVENOTIFICATIONITEMS_FIELD_NUMBER: _ClassVar[int]
    ZWAVEREADNODES_FIELD_NUMBER: _ClassVar[int]
    ZWAVEREADNODE_FIELD_NUMBER: _ClassVar[int]
    ZWAVEREMOVEENTRY_FIELD_NUMBER: _ClassVar[int]
    ZWAVEREMOVEFAILED_FIELD_NUMBER: _ClassVar[int]
    ZWAVEREPLACEFAILED_FIELD_NUMBER: _ClassVar[int]
    ZWAVERESET_FIELD_NUMBER: _ClassVar[int]
    ZWAVETEST_FIELD_NUMBER: _ClassVar[int]
    ZWAVEUPDATENODE_FIELD_NUMBER: _ClassVar[int]
    ZWAVEUPDATE_FIELD_NUMBER: _ClassVar[int]
    ZWaveAbort: _zwave_pb2.ZWaveAbortRequest
    ZWaveAddEntry: _zwave_pb2.ZWaveAddEntryRequest
    ZWaveExclude: _zwave_pb2.ZWaveExcludeRequest
    ZWaveHeal: _zwave_pb2.ZWaveHealRequest
    ZWaveHealthCheck: _zwave_pb2.ZWaveHealthCheckRequest
    ZWaveInclude: _zwave_pb2.ZWaveIncludeRequest
    ZWaveListEntries: _zwave_pb2.ZWaveListEntriesRequest
    ZWaveNotificationItems: _zwave_pb2.ZWaveNotificationItemsRequest
    ZWaveReadNode: _zwave_pb2.ZWaveNodeRequest
    ZWaveReadNodes: _zwave_pb2.ZWaveNodesRequest
    ZWaveRemoveEntry: _zwave_pb2.ZWaveRemoveEntryRequest
    ZWaveRemoveFailed: _zwave_pb2.ZWaveRemoveFailedRequest
    ZWaveReplaceFailed: _zwave_pb2.ZWaveReplaceFailedRequest
    ZWaveReset: _zwave_pb2.ZWaveResetRequest
    ZWaveTest: _zwave_pb2.ZWaveTestRequest
    ZWaveUpdate: _zwave_pb2.ZWaveUpdateRequest
    ZWaveUpdateNode: _zwave_pb2.ZWaveUpdateNodeRequest
    ZigbeeExclude: _zigbee_pb2.ZigbeeExcludeRequest
    ZigbeeGetNodes: _zigbee_pb2.ZigbeeNodesRequest
    ZigbeeInclude: _zigbee_pb2.ZigbeeIncludeRequest
    def __init__(self, AddonList: _Optional[_Union[_addon_pb2.AddonListRequest, _Mapping]] = ..., AddonAddThermostat: _Optional[_Union[_addon_pb2.AddonAddThermostatRequest, _Mapping]] = ..., WalkNodes: _Optional[_Union[_admin_pb2.WalkNodesRequest, _Mapping]] = ..., ReadLogs: _Optional[_Union[_admin_pb2.LogsRequest, _Mapping]] = ..., FollowLogs: _Optional[_Union[_admin_pb2.LogsRequest, _Mapping]] = ..., BatteryGet: _Optional[_Union[_battery_pb2.BatteryGetRequest, _Mapping]] = ..., ColorSet: _Optional[_Union[_color_pb2.ColorSetRequest, _Mapping]] = ..., ConfigurationList: _Optional[_Union[_configuration_pb2.ConfigurationListRequest, _Mapping]] = ..., ConfigurationGet: _Optional[_Union[_configuration_pb2.ConfigurationGetRequest, _Mapping]] = ..., ConfigurationSet: _Optional[_Union[_configuration_pb2.ConfigurationSetRequest, _Mapping]] = ..., ThermostatModeSet: _Optional[_Union[_thermostat_pb2.ThermostatModeSetRequest, _Mapping]] = ..., ThermostatModeSupGet: _Optional[_Union[_thermostat_pb2.ThermostatModeSupGetRequest, _Mapping]] = ..., ThermostatSetpointSet: _Optional[_Union[_thermostat_pb2.ThermostatSetpointSetRequest, _Mapping]] = ..., ThermostatFanModeSet: _Optional[_Union[_thermostat_pb2.ThermostatFanModeSetRequest, _Mapping]] = ..., DevicesList: _Optional[_Union[_devices_pb2.DevicesListRequest, _Mapping]] = ..., FirmwareUpload: _Optional[_Union[_firmware_pb2.FirmwareChunk, _Mapping]] = ..., FirmwareUpgrade: _Optional[_Union[_firmware_pb2.FirmwareUpgradeRequest, _Mapping]] = ..., FirmwareUpdate: _Optional[_Union[_firmware_pb2.FirmwareUpdateRequest, _Mapping]] = ..., FirmwareLatestVersion: _Optional[_Union[_firmware_pb2.FirmwareLatestVersionRequest, _Mapping]] = ..., Reboot: _Optional[_Union[_gateway_pb2.RebootRequest, _Mapping]] = ..., Restart: _Optional[_Union[_gateway_pb2.RestartRequest, _Mapping]] = ..., StartSupport: _Optional[_Union[_gateway_pb2.SupportRequest, _Mapping]] = ..., StopSupport: _Optional[_Union[_gateway_pb2.SupportRequest, _Mapping]] = ..., Info: _Optional[_Union[_info_pb2.InfoRequest, _Mapping]] = ..., LevelGet: _Optional[_Union[_level_pb2.LevelRequest, _Mapping]] = ..., LevelGetStep: _Optional[_Union[_level_pb2.LevelRequest, _Mapping]] = ..., LevelSet: _Optional[_Union[_level_pb2.LevelSetRequest, _Mapping]] = ..., LevelUp: _Optional[_Union[_level_pb2.LevelStepRequest, _Mapping]] = ..., LevelDown: _Optional[_Union[_level_pb2.LevelStepRequest, _Mapping]] = ..., LevelIncrease: _Optional[_Union[_level_pb2.LevelStepRequest, _Mapping]] = ..., LevelDecrease: _Optional[_Union[_level_pb2.LevelStepRequest, _Mapping]] = ..., LockSet: _Optional[_Union[_lock_pb2.LockSetRequest, _Mapping]] = ..., MeterGet: _Optional[_Union[_meter_pb2.MeterGetRequest, _Mapping]] = ..., MeterReset: _Optional[_Union[_meter_pb2.MeterResetRequest, _Mapping]] = ..., RollerShutterOpen: _Optional[_Union[_roller_shutter_pb2.RollerShutterRequest, _Mapping]] = ..., RollerShutterClose: _Optional[_Union[_roller_shutter_pb2.RollerShutterRequest, _Mapping]] = ..., RollerShutterSet: _Optional[_Union[_roller_shutter_pb2.RollerShutterSetRequest, _Mapping]] = ..., SirenGetTones: _Optional[_Union[_siren_pb2.SirenGetTonesRequest, _Mapping]] = ..., SirenPlayTone: _Optional[_Union[_siren_pb2.SirenPlayToneRequest, _Mapping]] = ..., SirenPlayDefaultTone: _Optional[_Union[_siren_pb2.SirenPlayDefaultToneRequest, _Mapping]] = ..., SirenGetDefaultTone: _Optional[_Union[_siren_pb2.SirenGetDefaultToneRequest, _Mapping]] = ..., SirenSetDefaultTone: _Optional[_Union[_siren_pb2.SirenSetDefaultToneRequest, _Mapping]] = ..., SirenGetVolume: _Optional[_Union[_siren_pb2.SirenGetVolumeRequest, _Mapping]] = ..., SirenSetVolume: _Optional[_Union[_siren_pb2.SirenSetVolumeRequest, _Mapping]] = ..., SwitchOn: _Optional[_Union[_switch_pb2.SwitchRequest, _Mapping]] = ..., SwitchOff: _Optional[_Union[_switch_pb2.SwitchRequest, _Mapping]] = ..., TemperatureGet: _Optional[_Union[_temperature_pb2.TemperatureGetRequest, _Mapping]] = ..., WiFiQuery: _Optional[_Union[_wifi_pb2.WiFiQueryRequest, _Mapping]] = ..., WiFiScan: _Optional[_Union[_wifi_pb2.WiFiScanRequest, _Mapping]] = ..., WiFiConnect: _Optional[_Union[_wifi_pb2.WiFiConnectRequest, _Mapping]] = ..., ZigbeeInclude: _Optional[_Union[_zigbee_pb2.ZigbeeIncludeRequest, _Mapping]] = ..., ZigbeeExclude: _Optional[_Union[_zigbee_pb2.ZigbeeExcludeRequest, _Mapping]] = ..., ZigbeeGetNodes: _Optional[_Union[_zigbee_pb2.ZigbeeNodesRequest, _Mapping]] = ..., ZWaveInclude: _Optional[_Union[_zwave_pb2.ZWaveIncludeRequest, _Mapping]] = ..., ZWaveExclude: _Optional[_Union[_zwave_pb2.ZWaveExcludeRequest, _Mapping]] = ..., ZWaveAbort: _Optional[_Union[_zwave_pb2.ZWaveAbortRequest, _Mapping]] = ..., ZWaveReadNodes: _Optional[_Union[_zwave_pb2.ZWaveNodesRequest, _Mapping]] = ..., ZWaveUpdate: _Optional[_Union[_zwave_pb2.ZWaveUpdateRequest, _Mapping]] = ..., ZWaveUpdateNode: _Optional[_Union[_zwave_pb2.ZWaveUpdateNodeRequest, _Mapping]] = ..., ZWaveReset: _Optional[_Union[_zwave_pb2.ZWaveResetRequest, _Mapping]] = ..., ZWaveListEntries: _Optional[_Union[_zwave_pb2.ZWaveListEntriesRequest, _Mapping]] = ..., ZWaveAddEntry: _Optional[_Union[_zwave_pb2.ZWaveAddEntryRequest, _Mapping]] = ..., ZWaveRemoveEntry: _Optional[_Union[_zwave_pb2.ZWaveRemoveEntryRequest, _Mapping]] = ..., ZWaveNotificationItems: _Optional[_Union[_zwave_pb2.ZWaveNotificationItemsRequest, _Mapping]] = ..., ZWaveTest: _Optional[_Union[_zwave_pb2.ZWaveTestRequest, _Mapping]] = ..., ZWaveHeal: _Optional[_Union[_zwave_pb2.ZWaveHealRequest, _Mapping]] = ..., ZWaveReplaceFailed: _Optional[_Union[_zwave_pb2.ZWaveReplaceFailedRequest, _Mapping]] = ..., ZWaveRemoveFailed: _Optional[_Union[_zwave_pb2.ZWaveRemoveFailedRequest, _Mapping]] = ..., ZWaveHealthCheck: _Optional[_Union[_zwave_pb2.ZWaveHealthCheckRequest, _Mapping]] = ..., ZWaveReadNode: _Optional[_Union[_zwave_pb2.ZWaveNodeRequest, _Mapping]] = ..., CarbonMonoxideGet: _Optional[_Union[_carbon_monoxide_pb2.CarbonMonoxideGetRequest, _Mapping]] = ..., EnableAdvertising: _Optional[_Union[_ble_pb2.AdvertisingRequest, _Mapping]] = ..., DisableAdvertising: _Optional[_Union[_ble_pb2.AdvertisingRequest, _Mapping]] = ..., UltravioletGet: _Optional[_Union[_ultraviolet_pb2.UltravioletGetRequest, _Mapping]] = ..., KeyUp: _Optional[_Union[_remote_pb2.RemoteRequest, _Mapping]] = ..., KeyDown: _Optional[_Union[_remote_pb2.RemoteRequest, _Mapping]] = ..., GateOpen: _Optional[_Union[_gate_pb2.GateRequest, _Mapping]] = ..., GateClose: _Optional[_Union[_gate_pb2.GateRequest, _Mapping]] = ..., GateCycle: _Optional[_Union[_gate_pb2.GateRequest, _Mapping]] = ..., StatusCheck: _Optional[_Union[_status_pb2.StatusCheckRequest, _Mapping]] = ..., GetStructure: _Optional[_Union[_structure_pb2.StructureRequest, _Mapping]] = ...) -> None: ...

class MessagingRequest(_message.Message):
    __slots__ = ["email", "push"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    PUSH_FIELD_NUMBER: _ClassVar[int]
    email: _messaging_pb2.EmailMessage
    push: _messaging_pb2.PushMessage
    def __init__(self, email: _Optional[_Union[_messaging_pb2.EmailMessage, _Mapping]] = ..., push: _Optional[_Union[_messaging_pb2.PushMessage, _Mapping]] = ...) -> None: ...

class MetricsNotification(_message.Message):
    __slots__ = ["data", "mac"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    MAC_FIELD_NUMBER: _ClassVar[int]
    data: _containers.RepeatedScalarFieldContainer[bytes]
    mac: str
    def __init__(self, mac: _Optional[str] = ..., data: _Optional[_Iterable[bytes]] = ...) -> None: ...

class PresenceNotification(_message.Message):
    __slots__ = ["build_time", "firmware_version", "git_commit", "mac", "version"]
    BUILD_TIME_FIELD_NUMBER: _ClassVar[int]
    FIRMWARE_VERSION_FIELD_NUMBER: _ClassVar[int]
    GIT_COMMIT_FIELD_NUMBER: _ClassVar[int]
    MAC_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    build_time: str
    firmware_version: str
    git_commit: str
    mac: str
    version: str
    def __init__(self, mac: _Optional[str] = ..., version: _Optional[str] = ..., git_commit: _Optional[str] = ..., build_time: _Optional[str] = ..., firmware_version: _Optional[str] = ...) -> None: ...

class CommandRequestType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class CommandRequestOption(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class CommandReplyType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from vemmio_client import metadata_pb2 as _metadata_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SirenGetDefaultToneRequest(_message.Message):
    __slots__ = ["metadata"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.DeviceMetadata
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ...) -> None: ...

class SirenGetDefaultToneResponse(_message.Message):
    __slots__ = ["tone"]
    TONE_FIELD_NUMBER: _ClassVar[int]
    tone: SirenTone
    def __init__(self, tone: _Optional[_Union[SirenTone, _Mapping]] = ...) -> None: ...

class SirenGetTonesRequest(_message.Message):
    __slots__ = ["metadata"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.DeviceMetadata
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ...) -> None: ...

class SirenGetTonesResponse(_message.Message):
    __slots__ = ["tones"]
    TONES_FIELD_NUMBER: _ClassVar[int]
    tones: _containers.RepeatedCompositeFieldContainer[SirenTone]
    def __init__(self, tones: _Optional[_Iterable[_Union[SirenTone, _Mapping]]] = ...) -> None: ...

class SirenGetVolumeRequest(_message.Message):
    __slots__ = ["metadata"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.DeviceMetadata
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ...) -> None: ...

class SirenGetVolumeResponse(_message.Message):
    __slots__ = ["volume"]
    VOLUME_FIELD_NUMBER: _ClassVar[int]
    volume: int
    def __init__(self, volume: _Optional[int] = ...) -> None: ...

class SirenPlayDefaultToneRequest(_message.Message):
    __slots__ = ["metadata"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.DeviceMetadata
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ...) -> None: ...

class SirenPlayDefaultToneResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class SirenPlayToneRequest(_message.Message):
    __slots__ = ["metadata", "tone_index"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    TONE_INDEX_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.DeviceMetadata
    tone_index: int
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ..., tone_index: _Optional[int] = ...) -> None: ...

class SirenPlayToneResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class SirenReport(_message.Message):
    __slots__ = ["state"]
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ACTIVE: SirenReport.State
    CLEAR: SirenReport.State
    STATE_FIELD_NUMBER: _ClassVar[int]
    state: SirenReport.State
    def __init__(self, state: _Optional[_Union[SirenReport.State, str]] = ...) -> None: ...

class SirenSetDefaultToneRequest(_message.Message):
    __slots__ = ["metadata", "tone_index"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    TONE_INDEX_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.DeviceMetadata
    tone_index: int
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ..., tone_index: _Optional[int] = ...) -> None: ...

class SirenSetDefaultToneResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class SirenSetVolumeRequest(_message.Message):
    __slots__ = ["metadata", "volume"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    VOLUME_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.DeviceMetadata
    volume: int
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ..., volume: _Optional[int] = ...) -> None: ...

class SirenSetVolumeResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class SirenTone(_message.Message):
    __slots__ = ["index", "label"]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    index: int
    label: str
    def __init__(self, index: _Optional[int] = ..., label: _Optional[str] = ...) -> None: ...

class ToneReport(_message.Message):
    __slots__ = ["state", "tone_index"]
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ACTIVE: ToneReport.State
    DEFAULT: ToneReport.State
    INACTIVE: ToneReport.State
    STATE_FIELD_NUMBER: _ClassVar[int]
    TONE_INDEX_FIELD_NUMBER: _ClassVar[int]
    state: ToneReport.State
    tone_index: int
    def __init__(self, state: _Optional[_Union[ToneReport.State, str]] = ..., tone_index: _Optional[int] = ...) -> None: ...

class VolumeReport(_message.Message):
    __slots__ = ["volume"]
    VOLUME_FIELD_NUMBER: _ClassVar[int]
    volume: int
    def __init__(self, volume: _Optional[int] = ...) -> None: ...



from vemmio_client import accelerometer_pb2 as _accelerometer_pb2
from vemmio_client import color_pb2 as _color_pb2
from vemmio_client import metadata_pb2 as _metadata_pb2
from vemmio_client import power_source_pb2 as _power_source_pb2
from vemmio_client import thermostat_pb2 as _thermostat_pb2
from vemmio_client import units_pb2 as _units_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AccelerometerCapability(_message.Message):
    __slots__ = ["axes"]
    class Axis(_message.Message):
        __slots__ = ["axis", "units"]
        AXIS_FIELD_NUMBER: _ClassVar[int]
        UNITS_FIELD_NUMBER: _ClassVar[int]
        axis: _accelerometer_pb2.AccelerometerAxis
        units: _containers.RepeatedScalarFieldContainer[_units_pb2.Unit]
        def __init__(self, axis: _Optional[_Union[_accelerometer_pb2.AccelerometerAxis, str]] = ..., units: _Optional[_Iterable[_Union[_units_pb2.Unit, str]]] = ...) -> None: ...
    AXES_FIELD_NUMBER: _ClassVar[int]
    axes: _containers.RepeatedCompositeFieldContainer[AccelerometerCapability.Axis]
    def __init__(self, axes: _Optional[_Iterable[_Union[AccelerometerCapability.Axis, _Mapping]]] = ...) -> None: ...

class BatteryCapability(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class Capability(_message.Message):
    __slots__ = ["accelerometer", "battery", "carbon_dioxide_detector", "carbon_monoxide_detector", "color", "configuration", "direction", "door", "doorbell", "emergency", "flood_detector", "gas_meter", "humidity", "illumination", "level", "lock", "motion_detector", "open_close", "power_meter", "power_source", "remote", "roller_shutter", "seismic", "siren", "smoke_detector", "switch", "tamper", "tap_tap", "temperature", "thermostat", "ultraviolet", "voltage", "water_meter"]
    ACCELEROMETER_FIELD_NUMBER: _ClassVar[int]
    BATTERY_FIELD_NUMBER: _ClassVar[int]
    CARBON_DIOXIDE_DETECTOR_FIELD_NUMBER: _ClassVar[int]
    CARBON_MONOXIDE_DETECTOR_FIELD_NUMBER: _ClassVar[int]
    COLOR_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    DIRECTION_FIELD_NUMBER: _ClassVar[int]
    DOORBELL_FIELD_NUMBER: _ClassVar[int]
    DOOR_FIELD_NUMBER: _ClassVar[int]
    EMERGENCY_FIELD_NUMBER: _ClassVar[int]
    FLOOD_DETECTOR_FIELD_NUMBER: _ClassVar[int]
    GAS_METER_FIELD_NUMBER: _ClassVar[int]
    HUMIDITY_FIELD_NUMBER: _ClassVar[int]
    ILLUMINATION_FIELD_NUMBER: _ClassVar[int]
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    LOCK_FIELD_NUMBER: _ClassVar[int]
    MOTION_DETECTOR_FIELD_NUMBER: _ClassVar[int]
    OPEN_CLOSE_FIELD_NUMBER: _ClassVar[int]
    POWER_METER_FIELD_NUMBER: _ClassVar[int]
    POWER_SOURCE_FIELD_NUMBER: _ClassVar[int]
    REMOTE_FIELD_NUMBER: _ClassVar[int]
    ROLLER_SHUTTER_FIELD_NUMBER: _ClassVar[int]
    SEISMIC_FIELD_NUMBER: _ClassVar[int]
    SIREN_FIELD_NUMBER: _ClassVar[int]
    SMOKE_DETECTOR_FIELD_NUMBER: _ClassVar[int]
    SWITCH_FIELD_NUMBER: _ClassVar[int]
    TAMPER_FIELD_NUMBER: _ClassVar[int]
    TAP_TAP_FIELD_NUMBER: _ClassVar[int]
    TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    THERMOSTAT_FIELD_NUMBER: _ClassVar[int]
    ULTRAVIOLET_FIELD_NUMBER: _ClassVar[int]
    VOLTAGE_FIELD_NUMBER: _ClassVar[int]
    WATER_METER_FIELD_NUMBER: _ClassVar[int]
    accelerometer: AccelerometerCapability
    battery: BatteryCapability
    carbon_dioxide_detector: CarbonDioxideDetectorCapability
    carbon_monoxide_detector: CarbonMonoxideDetectorCapability
    color: ColorCapability
    configuration: ConfigurationCapability
    direction: DirectionCapability
    door: DoorCapability
    doorbell: DoorbellCapability
    emergency: EmergencyCapability
    flood_detector: FloodDetectorCapability
    gas_meter: MeterCapability
    humidity: HumidityCapability
    illumination: IlluminationCapability
    level: LevelCapability
    lock: LockCapability
    motion_detector: MotionDetectorCapability
    open_close: OpenCloseCapability
    power_meter: MeterCapability
    power_source: PowerSourceCapability
    remote: RemoteCapability
    roller_shutter: RollerShutterCapability
    seismic: SeismicCapability
    siren: SirenCapability
    smoke_detector: SmokeDetectorCapability
    switch: SwitchCapability
    tamper: TamperCapability
    tap_tap: TapTapCapability
    temperature: TemperatureCapability
    thermostat: ThermostatCapability
    ultraviolet: UltravioletCapability
    voltage: VoltageCapability
    water_meter: MeterCapability
    def __init__(self, switch: _Optional[_Union[SwitchCapability, _Mapping]] = ..., power_meter: _Optional[_Union[MeterCapability, _Mapping]] = ..., gas_meter: _Optional[_Union[MeterCapability, _Mapping]] = ..., water_meter: _Optional[_Union[MeterCapability, _Mapping]] = ..., open_close: _Optional[_Union[OpenCloseCapability, _Mapping]] = ..., smoke_detector: _Optional[_Union[SmokeDetectorCapability, _Mapping]] = ..., motion_detector: _Optional[_Union[MotionDetectorCapability, _Mapping]] = ..., flood_detector: _Optional[_Union[FloodDetectorCapability, _Mapping]] = ..., carbon_monoxide_detector: _Optional[_Union[CarbonMonoxideDetectorCapability, _Mapping]] = ..., thermostat: _Optional[_Union[ThermostatCapability, _Mapping]] = ..., temperature: _Optional[_Union[TemperatureCapability, _Mapping]] = ..., humidity: _Optional[_Union[HumidityCapability, _Mapping]] = ..., illumination: _Optional[_Union[IlluminationCapability, _Mapping]] = ..., direction: _Optional[_Union[DirectionCapability, _Mapping]] = ..., tamper: _Optional[_Union[TamperCapability, _Mapping]] = ..., emergency: _Optional[_Union[EmergencyCapability, _Mapping]] = ..., door: _Optional[_Union[DoorCapability, _Mapping]] = ..., tap_tap: _Optional[_Union[TapTapCapability, _Mapping]] = ..., color: _Optional[_Union[ColorCapability, _Mapping]] = ..., level: _Optional[_Union[LevelCapability, _Mapping]] = ..., battery: _Optional[_Union[BatteryCapability, _Mapping]] = ..., lock: _Optional[_Union[LockCapability, _Mapping]] = ..., remote: _Optional[_Union[RemoteCapability, _Mapping]] = ..., power_source: _Optional[_Union[PowerSourceCapability, _Mapping]] = ..., roller_shutter: _Optional[_Union[RollerShutterCapability, _Mapping]] = ..., configuration: _Optional[_Union[ConfigurationCapability, _Mapping]] = ..., doorbell: _Optional[_Union[DoorbellCapability, _Mapping]] = ..., siren: _Optional[_Union[SirenCapability, _Mapping]] = ..., accelerometer: _Optional[_Union[AccelerometerCapability, _Mapping]] = ..., seismic: _Optional[_Union[SeismicCapability, _Mapping]] = ..., carbon_dioxide_detector: _Optional[_Union[CarbonDioxideDetectorCapability, _Mapping]] = ..., voltage: _Optional[_Union[VoltageCapability, _Mapping]] = ..., ultraviolet: _Optional[_Union[UltravioletCapability, _Mapping]] = ...) -> None: ...

class CarbonDioxideDetectorCapability(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CarbonMonoxideDetectorCapability(_message.Message):
    __slots__ = ["units"]
    UNITS_FIELD_NUMBER: _ClassVar[int]
    units: _containers.RepeatedScalarFieldContainer[_units_pb2.Unit]
    def __init__(self, units: _Optional[_Iterable[_Union[_units_pb2.Unit, str]]] = ...) -> None: ...

class ColorCapability(_message.Message):
    __slots__ = ["components"]
    COMPONENTS_FIELD_NUMBER: _ClassVar[int]
    components: _containers.RepeatedScalarFieldContainer[_color_pb2.ColorComponent]
    def __init__(self, components: _Optional[_Iterable[_Union[_color_pb2.ColorComponent, str]]] = ...) -> None: ...

class ConfigurationCapability(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class Device(_message.Message):
    __slots__ = ["capabilities", "group", "i18n", "metadata", "name"]
    class Group(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    CAMERAS: Device.Group
    CAPABILITIES_FIELD_NUMBER: _ClassVar[int]
    CLIMATE: Device.Group
    DOORBELLS: Device.Group
    GATES: Device.Group
    GATEWAYS: Device.Group
    GROUP_FIELD_NUMBER: _ClassVar[int]
    I18N_FIELD_NUMBER: _ClassVar[int]
    LIGHTS: Device.Group
    METADATA_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OTHER: Device.Group
    POWER: Device.Group
    ROLLER_SHUTTERS: Device.Group
    SECURITY: Device.Group
    SOUND: Device.Group
    capabilities: _containers.RepeatedCompositeFieldContainer[Capability]
    group: Device.Group
    i18n: str
    metadata: _metadata_pb2.DeviceMetadata
    name: str
    def __init__(self, name: _Optional[str] = ..., metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ..., capabilities: _Optional[_Iterable[_Union[Capability, _Mapping]]] = ..., i18n: _Optional[str] = ..., group: _Optional[_Union[Device.Group, str]] = ...) -> None: ...

class DevicesListRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DevicesListResponse(_message.Message):
    __slots__ = ["devices"]
    DEVICES_FIELD_NUMBER: _ClassVar[int]
    devices: _containers.RepeatedCompositeFieldContainer[Device]
    def __init__(self, devices: _Optional[_Iterable[_Union[Device, _Mapping]]] = ...) -> None: ...

class DirectionCapability(_message.Message):
    __slots__ = ["units"]
    UNITS_FIELD_NUMBER: _ClassVar[int]
    units: _containers.RepeatedScalarFieldContainer[_units_pb2.Unit]
    def __init__(self, units: _Optional[_Iterable[_Union[_units_pb2.Unit, str]]] = ...) -> None: ...

class DoorCapability(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DoorbellCapability(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class EmergencyCapability(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class FloodDetectorCapability(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class HumidityCapability(_message.Message):
    __slots__ = ["units"]
    UNITS_FIELD_NUMBER: _ClassVar[int]
    units: _containers.RepeatedScalarFieldContainer[_units_pb2.Unit]
    def __init__(self, units: _Optional[_Iterable[_Union[_units_pb2.Unit, str]]] = ...) -> None: ...

class IlluminationCapability(_message.Message):
    __slots__ = ["units"]
    UNITS_FIELD_NUMBER: _ClassVar[int]
    units: _containers.RepeatedScalarFieldContainer[_units_pb2.Unit]
    def __init__(self, units: _Optional[_Iterable[_Union[_units_pb2.Unit, str]]] = ...) -> None: ...

class LevelCapability(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class LockCapability(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MeterCapability(_message.Message):
    __slots__ = ["reset", "units"]
    RESET_FIELD_NUMBER: _ClassVar[int]
    UNITS_FIELD_NUMBER: _ClassVar[int]
    reset: bool
    units: _containers.RepeatedScalarFieldContainer[_units_pb2.Unit]
    def __init__(self, units: _Optional[_Iterable[_Union[_units_pb2.Unit, str]]] = ..., reset: bool = ...) -> None: ...

class MotionDetectorCapability(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class OpenCloseCapability(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class PowerSourceCapability(_message.Message):
    __slots__ = ["events"]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    events: _containers.RepeatedScalarFieldContainer[_power_source_pb2.PowerSourceEvent]
    def __init__(self, events: _Optional[_Iterable[_Union[_power_source_pb2.PowerSourceEvent, str]]] = ...) -> None: ...

class RemoteCapability(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class RollerShutterCapability(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class SeismicCapability(_message.Message):
    __slots__ = ["intensity", "magnitude"]
    INTENSITY_FIELD_NUMBER: _ClassVar[int]
    MAGNITUDE_FIELD_NUMBER: _ClassVar[int]
    intensity: _containers.RepeatedScalarFieldContainer[_units_pb2.Unit]
    magnitude: _containers.RepeatedScalarFieldContainer[_units_pb2.Unit]
    def __init__(self, intensity: _Optional[_Iterable[_Union[_units_pb2.Unit, str]]] = ..., magnitude: _Optional[_Iterable[_Union[_units_pb2.Unit, str]]] = ...) -> None: ...

class SirenCapability(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class SmokeDetectorCapability(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class SwitchCapability(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class TamperCapability(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class TapTapCapability(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class TemperatureCapability(_message.Message):
    __slots__ = ["units"]
    UNITS_FIELD_NUMBER: _ClassVar[int]
    units: _containers.RepeatedScalarFieldContainer[_units_pb2.Unit]
    def __init__(self, units: _Optional[_Iterable[_Union[_units_pb2.Unit, str]]] = ...) -> None: ...

class ThermostatCapability(_message.Message):
    __slots__ = ["ranges"]
    RANGES_FIELD_NUMBER: _ClassVar[int]
    ranges: _containers.RepeatedCompositeFieldContainer[_thermostat_pb2.ThermostatSetpointRange]
    def __init__(self, ranges: _Optional[_Iterable[_Union[_thermostat_pb2.ThermostatSetpointRange, _Mapping]]] = ...) -> None: ...

class UltravioletCapability(_message.Message):
    __slots__ = ["units"]
    UNITS_FIELD_NUMBER: _ClassVar[int]
    units: _containers.RepeatedScalarFieldContainer[_units_pb2.Unit]
    def __init__(self, units: _Optional[_Iterable[_Union[_units_pb2.Unit, str]]] = ...) -> None: ...

class VoltageCapability(_message.Message):
    __slots__ = ["units"]
    UNITS_FIELD_NUMBER: _ClassVar[int]
    units: _containers.RepeatedScalarFieldContainer[_units_pb2.Unit]
    def __init__(self, units: _Optional[_Iterable[_Union[_units_pb2.Unit, str]]] = ...) -> None: ...



from vemmio_client import metadata_pb2 as _metadata_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BatteryGetRequest(_message.Message):
    __slots__ = ["metadata"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.DeviceMetadata
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ...) -> None: ...

class BatteryGetResponse(_message.Message):
    __slots__ = ["level"]
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    level: int
    def __init__(self, level: _Optional[int] = ...) -> None: ...

class BatteryReport(_message.Message):
    __slots__ = ["level"]
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    level: int
    def __init__(self, level: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
FIRMWARE_UPDATE_STATUS_COMPLETE: FirmwareUpdateStatus
FIRMWARE_UPDATE_STATUS_FAILED: FirmwareUpdateStatus
FIRMWARE_UPDATE_STATUS_IN_PROGRESS: FirmwareUpdateStatus
FIRMWARE_UPDATE_STATUS_UNKNOWN: FirmwareUpdateStatus
FIRMWARE_UPDATE_STATUS_UP_TO_DATE: FirmwareUpdateStatus

class FirmwareChunk(_message.Message):
    __slots__ = ["data", "index"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    index: int
    def __init__(self, data: _Optional[bytes] = ..., index: _Optional[int] = ...) -> None: ...

class FirmwareChunkAck(_message.Message):
    __slots__ = ["filename"]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    filename: str
    def __init__(self, filename: _Optional[str] = ...) -> None: ...

class FirmwareLatestVersionRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class FirmwareLatestVersionResponse(_message.Message):
    __slots__ = ["version"]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    version: str
    def __init__(self, version: _Optional[str] = ...) -> None: ...

class FirmwareUpdateRequest(_message.Message):
    __slots__ = ["version"]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    version: str
    def __init__(self, version: _Optional[str] = ...) -> None: ...

class FirmwareUpdateResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class FirmwareUpdateStatusReport(_message.Message):
    __slots__ = ["progress", "status", "version"]
    PROGRESS_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    progress: int
    status: FirmwareUpdateStatus
    version: str
    def __init__(self, status: _Optional[_Union[FirmwareUpdateStatus, str]] = ..., progress: _Optional[int] = ..., version: _Optional[str] = ...) -> None: ...

class FirmwareUpgradeAck(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class FirmwareUpgradeRequest(_message.Message):
    __slots__ = ["filename", "sha256"]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    SHA256_FIELD_NUMBER: _ClassVar[int]
    filename: str
    sha256: str
    def __init__(self, filename: _Optional[str] = ..., sha256: _Optional[str] = ...) -> None: ...

class FirmwareUpdateStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AddonMetadata(_message.Message):
    __slots__ = ["uuid"]
    UUID_FIELD_NUMBER: _ClassVar[int]
    uuid: str
    def __init__(self, uuid: _Optional[str] = ...) -> None: ...

class AliasMetadata(_message.Message):
    __slots__ = ["name"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class DeviceMetadata(_message.Message):
    __slots__ = ["addon", "alias", "mqtt", "zigbee", "zwave"]
    ADDON_FIELD_NUMBER: _ClassVar[int]
    ALIAS_FIELD_NUMBER: _ClassVar[int]
    MQTT_FIELD_NUMBER: _ClassVar[int]
    ZIGBEE_FIELD_NUMBER: _ClassVar[int]
    ZWAVE_FIELD_NUMBER: _ClassVar[int]
    addon: AddonMetadata
    alias: AliasMetadata
    mqtt: MQTTMetadata
    zigbee: ZigbeeMetadata
    zwave: ZWaveMetadata
    def __init__(self, zwave: _Optional[_Union[ZWaveMetadata, _Mapping]] = ..., zigbee: _Optional[_Union[ZigbeeMetadata, _Mapping]] = ..., addon: _Optional[_Union[AddonMetadata, _Mapping]] = ..., alias: _Optional[_Union[AliasMetadata, _Mapping]] = ..., mqtt: _Optional[_Union[MQTTMetadata, _Mapping]] = ...) -> None: ...

class MQTTMetadata(_message.Message):
    __slots__ = ["device_id"]
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    device_id: bytes
    def __init__(self, device_id: _Optional[bytes] = ...) -> None: ...

class ZWaveMetadata(_message.Message):
    __slots__ = ["endpoint_id", "node_id"]
    ENDPOINT_ID_FIELD_NUMBER: _ClassVar[int]
    NODE_ID_FIELD_NUMBER: _ClassVar[int]
    endpoint_id: int
    node_id: int
    def __init__(self, node_id: _Optional[int] = ..., endpoint_id: _Optional[int] = ...) -> None: ...

class ZigbeeMetadata(_message.Message):
    __slots__ = ["endpoint", "eui64_addr"]
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    EUI64_ADDR_FIELD_NUMBER: _ClassVar[int]
    endpoint: int
    eui64_addr: str
    def __init__(self, eui64_addr: _Optional[str] = ..., endpoint: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/reports.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from vemmio_client import accelerometer_pb2 as vemmio__client_dot_accelerometer__pb2
from vemmio_client import battery_pb2 as vemmio__client_dot_battery__pb2
from vemmio_client import bsensor_pb2 as vemmio__client_dot_bsensor__pb2
from vemmio_client import carbon_dioxide_pb2 as vemmio__client_dot_carbon__dioxide__pb2
from vemmio_client import carbon_monoxide_pb2 as vemmio__client_dot_carbon__monoxide__pb2
from vemmio_client import color_pb2 as vemmio__client_dot_color__pb2
from vemmio_client import door_pb2 as vemmio__client_dot_door__pb2
from vemmio_client import doorbell_pb2 as vemmio__client_dot_doorbell__pb2
from vemmio_client import emergency_pb2 as vemmio__client_dot_emergency__pb2
from vemmio_client import firmware_pb2 as vemmio__client_dot_firmware__pb2
from vemmio_client import flood_pb2 as vemmio__client_dot_flood__pb2
from vemmio_client import gate_pb2 as vemmio__client_dot_gate__pb2
from vemmio_client import level_pb2 as vemmio__client_dot_level__pb2
from vemmio_client import lock_pb2 as vemmio__client_dot_lock__pb2
from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2
from vemmio_client import meter_pb2 as vemmio__client_dot_meter__pb2
from vemmio_client import power_source_pb2 as vemmio__client_dot_power__source__pb2
from vemmio_client import remote_pb2 as vemmio__client_dot_remote__pb2
from vemmio_client import roller_shutter_pb2 as vemmio__client_dot_roller__shutter__pb2
from vemmio_client import seismic_pb2 as vemmio__client_dot_seismic__pb2
from vemmio_client import sensor_pb2 as vemmio__client_dot_sensor__pb2
from vemmio_client import siren_pb2 as vemmio__client_dot_siren__pb2
from vemmio_client import smoke_pb2 as vemmio__client_dot_smoke__pb2
from vemmio_client import status_pb2 as vemmio__client_dot_status__pb2
from vemmio_client import structure_pb2 as vemmio__client_dot_structure__pb2
from vemmio_client import switch_pb2 as vemmio__client_dot_switch__pb2
from vemmio_client import tamper_pb2 as vemmio__client_dot_tamper__pb2
from vemmio_client import taptap_pb2 as vemmio__client_dot_taptap__pb2
from vemmio_client import temperature_pb2 as vemmio__client_dot_temperature__pb2
from vemmio_client import thermostat_pb2 as vemmio__client_dot_thermostat__pb2
from vemmio_client import ultraviolet_pb2 as vemmio__client_dot_ultraviolet__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bvemmio_client/reports.proto\x12\x08vemmiopb\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!vemmio_client/accelerometer.proto\x1a\x1bvemmio_client/battery.proto\x1a\x1bvemmio_client/bsensor.proto\x1a\"vemmio_client/carbon_dioxide.proto\x1a#vemmio_client/carbon_monoxide.proto\x1a\x19vemmio_client/color.proto\x1a\x18vemmio_client/door.proto\x1a\x1cvemmio_client/doorbell.proto\x1a\x1dvemmio_client/emergency.proto\x1a\x1cvemmio_client/firmware.proto\x1a\x19vemmio_client/flood.proto\x1a\x18vemmio_client/gate.proto\x1a\x19vemmio_client/level.proto\x1a\x18vemmio_client/lock.proto\x1a\x1cvemmio_client/metadata.proto\x1a\x19vemmio_client/meter.proto\x1a vemmio_client/power_source.proto\x1a\x1avemmio_client/remote.proto\x1a\"vemmio_client/roller_shutter.proto\x1a\x1bvemmio_client/seismic.proto\x1a\x1avemmio_client/sensor.proto\x1a\x19vemmio_client/siren.proto\x1a\x19vemmio_client/smoke.proto\x1a\x1avemmio_client/status.proto\x1a\x1dvemmio_client/structure.proto\x1a\x1avemmio_client/switch.proto\x1a\x1avemmio_client/tamper.proto\x1a\x1avemmio_client/taptap.proto\x1a\x1fvemmio_client/temperature.proto\x1a\x1evemmio_client/thermostat.proto\x1a\x1fvemmio_client/ultraviolet.proto\"\x0f\n\rReportRequest\"\xc9\x0f\n\x0c\x44\x65viceReport\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x06switch\x18\x03 \x01(\x0b\x32\x16.vemmiopb.SwitchReportH\x00\x12,\n\x0bpower_meter\x18\x04 \x01(\x0b\x32\x15.vemmiopb.MeterReportH\x00\x12*\n\tgas_meter\x18\x05 \x01(\x0b\x32\x15.vemmiopb.MeterReportH\x00\x12,\n\x0bwater_meter\x18\x06 \x01(\x0b\x32\x15.vemmiopb.MeterReportH\x00\x12/\n\nopen_close\x18\x07 \x01(\x0b\x32\x19.vemmiopb.OpenCloseReportH\x00\x12&\n\x05smoke\x18\x08 \x01(\x0b\x32\x15.vemmiopb.SmokeReportH\x00\x12(\n\x06motion\x18\t \x01(\x0b\x32\x16.vemmiopb.MotionReportH\x00\x12&\n\x05\x66lood\x18\n \x01(\x0b\x32\x15.vemmiopb.FloodReportH\x00\x12\x44\n\x15\x63\x61rbon_monoxide_state\x18\x0b \x01(\x0b\x32#.vemmiopb.CarbonMonoxideStateReportH\x00\x12\x32\n\x0btemperature\x18\x0c \x01(\x0b\x32\x1b.vemmiopb.TemperatureReportH\x00\x12,\n\x08humidity\x18\r \x01(\x0b\x32\x18.vemmiopb.HumidityReportH\x00\x12\x34\n\x0cillumination\x18\x0e \x01(\x0b\x32\x1c.vemmiopb.IlluminationReportH\x00\x12.\n\tdirection\x18\x0f \x01(\x0b\x32\x19.vemmiopb.DirectionReportH\x00\x12\x39\n\x0fthermostat_mode\x18\x10 \x01(\x0b\x32\x1e.vemmiopb.ThermostatModeReportH\x00\x12\x41\n\x13thermostat_setpoint\x18\x11 \x01(\x0b\x32\".vemmiopb.ThermostatSetpointReportH\x00\x12@\n\x13thermostat_fan_mode\x18\x12 \x01(\x0b\x32!.vemmiopb.ThermostatFanModeReportH\x00\x12(\n\x06tamper\x18\x13 \x01(\x0b\x32\x16.vemmiopb.TamperReportH\x00\x12.\n\temergency\x18\x14 \x01(\x0b\x32\x19.vemmiopb.EmergencyReportH\x00\x12$\n\x04\x64oor\x18\x15 \x01(\x0b\x32\x14.vemmiopb.DoorReportH\x00\x12)\n\x07tap_tap\x18\x16 \x01(\x0b\x32\x16.vemmiopb.TapTapReportH\x00\x12&\n\x05\x63olor\x18\x17 \x01(\x0b\x32\x15.vemmiopb.ColorReportH\x00\x12&\n\x05level\x18\x18 \x01(\x0b\x32\x15.vemmiopb.LevelReportH\x00\x12*\n\x07\x62\x61ttery\x18\x19 \x01(\x0b\x32\x17.vemmiopb.BatteryReportH\x00\x12(\n\x06remote\x18\x1a \x01(\x0b\x32\x16.vemmiopb.RemoteReportH\x00\x12$\n\x04lock\x18\x1b \x01(\x0b\x32\x14.vemmiopb.LockReportH\x00\x12,\n\x08\x64oorbell\x18\x1d \x01(\x0b\x32\x18.vemmiopb.DoorbellReportH\x00\x12\x33\n\x0cpower_source\x18\x1e \x01(\x0b\x32\x1b.vemmiopb.PowerSourceReportH\x00\x12&\n\x05siren\x18\x1f \x01(\x0b\x32\x15.vemmiopb.SirenReportH\x00\x12$\n\x04tone\x18  \x01(\x0b\x32\x14.vemmiopb.ToneReportH\x00\x12(\n\x06volume\x18! \x01(\x0b\x32\x16.vemmiopb.VolumeReportH\x00\x12\x36\n\raccelerometer\x18\" \x01(\x0b\x32\x1d.vemmiopb.AccelerometerReportH\x00\x12=\n\x11seismic_intensity\x18# \x01(\x0b\x32 .vemmiopb.SeismicIntensityReportH\x00\x12=\n\x11seismic_magnitude\x18$ \x01(\x0b\x32 .vemmiopb.SeismicMagnitudeReportH\x00\x12\x42\n\x14roller_shutter_level\x18% \x01(\x0b\x32\".vemmiopb.RollerShutterLevelReportH\x00\x12\x37\n\x0e\x63\x61rbon_dioxide\x18& \x01(\x0b\x32\x1d.vemmiopb.CarbonDioxideReportH\x00\x12\x44\n\x15\x63\x61rbon_monoxide_value\x18\' \x01(\x0b\x32#.vemmiopb.CarbonMonoxideValueReportH\x00\x12\x32\n\x0bultraviolet\x18( \x01(\x0b\x32\x1b.vemmiopb.UltravioletReportH\x00\x12$\n\x04gate\x18) \x01(\x0b\x32\x14.vemmiopb.GateReportH\x00\x42\x08\n\x06reportJ\x04\x08\x1c\x10\x1d\"\xd7\x01\n\x12\x43onnectivityReport\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x05state\x18\x02 \x01(\x0e\x32\".vemmiopb.ConnectivityReport.State\x12)\n\x06uptime\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"4\n\x05State\x12\x10\n\x0c\x44ISCONNECTED\x10\x00\x12\r\n\tCONNECTED\x10\x01\x12\n\n\x06UPTIME\x10\x02\"\xb9\x02\n\rGatewayReport\x12\x0b\n\x03mac\x18\x01 \x01(\t\x12\x34\n\x0c\x63onnectivity\x18\x02 \x01(\x0b\x32\x1c.vemmiopb.ConnectivityReportH\x00\x12(\n\x06\x64\x65vice\x18\x03 \x01(\x0b\x32\x16.vemmiopb.DeviceReportH\x00\x12\x33\n\x0cstatus_check\x18\x05 \x01(\x0b\x32\x1b.vemmiopb.StatusCheckReportH\x00\x12\x46\n\x16\x66irmware_update_status\x18\x06 \x01(\x0b\x32$.vemmiopb.FirmwareUpdateStatusReportH\x00\x12.\n\tstructure\x18\x07 \x01(\x0b\x32\x19.vemmiopb.StructureReportH\x00\x42\x08\n\x06reportJ\x04\x08\x04\x10\x05\x32I\n\x07Reports\x12>\n\tSubscribe\x12\x17.vemmiopb.ReportRequest\x1a\x16.vemmiopb.DeviceReport0\x01\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.reports_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _REPORTREQUEST._serialized_start=1029
  _REPORTREQUEST._serialized_end=1044
  _DEVICEREPORT._serialized_start=1047
  _DEVICEREPORT._serialized_end=3040
  _CONNECTIVITYREPORT._serialized_start=3043
  _CONNECTIVITYREPORT._serialized_end=3258
  _CONNECTIVITYREPORT_STATE._serialized_start=3206
  _CONNECTIVITYREPORT_STATE._serialized_end=3258
  _GATEWAYREPORT._serialized_start=3261
  _GATEWAYREPORT._serialized_end=3574
  _REPORTS._serialized_start=3576
  _REPORTS._serialized_end=3649
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

AMPERE: Unit
CELSIUS: Unit
CUBIC_FEET: Unit
CUBIC_METERS: Unit
DEGREES: Unit
DESCRIPTOR: _descriptor.FileDescriptor
FAHRENHEIT: Unit
KVAH: Unit
KWH: Unit
LUX: Unit
MERCALLI: Unit
METER_PER_SECOND_SQUARED: Unit
PARTS_PER_MILLION: Unit
PERCENTAGE: Unit
POWER_FACTOR: Unit
PULSE_COUNT: Unit
UNKNOWN: Unit
US_GALLONS: Unit
VOLT: Unit
WATT: Unit

class Unit(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/carbon_dioxide.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"vemmio_client/carbon_dioxide.proto\x12\x08vemmiopb\"\xb4\x01\n\x13\x43\x61rbonDioxideReport\x12+\n\x05state\x18\x01 \x01(\x0e\x32\x1c.vemmiopb.CarbonDioxideState\x12\x37\n\x0breplacement\x18\x02 \x01(\x0e\x32\".vemmiopb.CarbonDioxideReplacement\x12\x37\n\x0bmaintenance\x18\x03 \x01(\x0e\x32\".vemmiopb.CarbonDioxideMaintenance*\x9d\x02\n\x12\x43\x61rbonDioxideState\x12$\n CARBON_DIOXIDE_STATE_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x43\x41RBON_DIOXIDE_STATE_CLEAR\x10\x01\x12!\n\x1d\x43\x41RBON_DIOXIDE_STATE_DETECTED\x10\x02\x12\x1d\n\x19\x43\x41RBON_DIOXIDE_STATE_TEST\x10\x03\x12!\n\x1d\x43\x41RBON_DIOXIDE_STATE_SILENCED\x10\x04\x12-\n)CARBON_DIOXIDE_STATE_REPLACEMENT_REQUIRED\x10\x05\x12-\n)CARBON_DIOXIDE_STATE_MAINTENANCE_REQUIRED\x10\x06*j\n\x18\x43\x61rbonDioxideReplacement\x12*\n&CARBON_DIOXIDE_REPLACEMENT_UNSPECIFIED\x10\x00\x12\"\n\x1e\x43\x41RBON_DIOXIDE_REPLACEMENT_EOL\x10\x01*z\n\x18\x43\x61rbonDioxideMaintenance\x12*\n&CARBON_DIOXIDE_MAINTENANCE_UNSPECIFIED\x10\x00\x12\x32\n.CARBON_DIOXIDE_MAINTENANCE_PERIODIC_INSPECTION\x10\x01\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.carbon_dioxide_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _CARBONDIOXIDESTATE._serialized_start=232
  _CARBONDIOXIDESTATE._serialized_end=517
  _CARBONDIOXIDEREPLACEMENT._serialized_start=519
  _CARBONDIOXIDEREPLACEMENT._serialized_end=625
  _CARBONDIOXIDEMAINTENANCE._serialized_start=627
  _CARBONDIOXIDEMAINTENANCE._serialized_end=749
  _CARBONDIOXIDEREPORT._serialized_start=49
  _CARBONDIOXIDEREPORT._serialized_end=229
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/lock.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18vemmio_client/lock.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\"^\n\x0eLockSetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12 \n\x04mode\x18\x02 \x01(\x0e\x32\x12.vemmiopb.LockMode\"\x0e\n\x0cLockResponse\".\n\nLockReport\x12 \n\x04mode\x18\x01 \x01(\x0e\x32\x12.vemmiopb.LockMode*\xac\x01\n\x08LockMode\x12\x0e\n\nLOCK_UNSEC\x10\x00\x12\x14\n\x10LOCK_UNSEC_TMOUT\x10\x01\x12\x11\n\rLOCK_UNSEC_IN\x10\x10\x12\x17\n\x13LOCK_UNSEC_IN_TMOUT\x10\x11\x12\x12\n\x0eLOCK_UNSEC_OUT\x10 \x12\x18\n\x14LOCK_UNSEC_OUT_TMOUT\x10!\x12\x11\n\x0cLOCK_UNKNOWN\x10\xfe\x01\x12\r\n\x08LOCK_SEC\x10\xff\x01\x32\x43\n\x04Lock\x12;\n\x07LockSet\x12\x18.vemmiopb.LockSetRequest\x1a\x16.vemmiopb.LockResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.lock_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _LOCKMODE._serialized_start=229
  _LOCKMODE._serialized_end=401
  _LOCKSETREQUEST._serialized_start=68
  _LOCKSETREQUEST._serialized_end=162
  _LOCKRESPONSE._serialized_start=164
  _LOCKRESPONSE._serialized_end=178
  _LOCKREPORT._serialized_start=180
  _LOCKREPORT._serialized_end=226
  _LOCK._serialized_start=403
  _LOCK._serialized_end=470
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/wifi.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18vemmio_client/wifi.proto\x12\x08vemmiopb\x1a\x1fgoogle/protobuf/timestamp.proto\"\x12\n\x10WiFiQueryRequest\"o\n\x11WiFiQueryResponse\x12+\n\ninterfaces\x18\x01 \x03(\x0b\x32\x17.vemmiopb.WiFiInterface\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x11\n\x0fWiFiScanRequest\"3\n\x10WiFiScanResponse\x12\x1f\n\x04\x62sss\x18\x01 \x03(\x0b\x32\x11.vemmiopb.WiFiBSS\"/\n\x12WiFiConnectRequest\x12\x0c\n\x04ssid\x18\x01 \x01(\t\x12\x0b\n\x03psk\x18\x02 \x01(\t\"\x15\n\x13WiFiConnectResponse\"}\n\rWiFiInterface\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rhardware_addr\x18\x02 \x01(\x0c\x12\x1e\n\x03\x62ss\x18\x03 \x01(\x0b\x32\x11.vemmiopb.WiFiBSS\x12\'\n\x08stations\x18\x04 \x03(\x0b\x32\x15.vemmiopb.WiFiStation\"=\n\x07WiFiBSS\x12\x0c\n\x04ssid\x18\x01 \x01(\t\x12\x11\n\tfrequency\x18\x02 \x01(\x05\x12\x11\n\tlast_seen\x18\x03 \x01(\x03\"Y\n\x0bWiFiStation\x12\x15\n\rhardware_addr\x18\x01 \x01(\x0c\x12\x0e\n\x06signal\x18\x02 \x01(\x05\x12\x11\n\tconnected\x18\x03 \x01(\x03\x12\x10\n\x08inactive\x18\x04 \x01(\x03\x32\xdb\x01\n\x04WiFi\x12\x44\n\tWiFiQuery\x12\x1a.vemmiopb.WiFiQueryRequest\x1a\x1b.vemmiopb.WiFiQueryResponse\x12\x41\n\x08WiFiScan\x12\x19.vemmiopb.WiFiScanRequest\x1a\x1a.vemmiopb.WiFiScanResponse\x12J\n\x0bWiFiConnect\x12\x1c.vemmiopb.WiFiConnectRequest\x1a\x1d.vemmiopb.WiFiConnectResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.wifi_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _WIFIQUERYREQUEST._serialized_start=71
  _WIFIQUERYREQUEST._serialized_end=89
  _WIFIQUERYRESPONSE._serialized_start=91
  _WIFIQUERYRESPONSE._serialized_end=202
  _WIFISCANREQUEST._serialized_start=204
  _WIFISCANREQUEST._serialized_end=221
  _WIFISCANRESPONSE._serialized_start=223
  _WIFISCANRESPONSE._serialized_end=274
  _WIFICONNECTREQUEST._serialized_start=276
  _WIFICONNECTREQUEST._serialized_end=323
  _WIFICONNECTRESPONSE._serialized_start=325
  _WIFICONNECTRESPONSE._serialized_end=346
  _WIFIINTERFACE._serialized_start=348
  _WIFIINTERFACE._serialized_end=473
  _WIFIBSS._serialized_start=475
  _WIFIBSS._serialized_end=536
  _WIFISTATION._serialized_start=538
  _WIFISTATION._serialized_end=627
  _WIFI._serialized_start=630
  _WIFI._serialized_end=849
# @@protoc_insertion_point(module_scope)



from vemmio_client import metadata_pb2 as _metadata_pb2
from vemmio_client import units_pb2 as _units_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

CARBON_MONOXIDE_MAINTENANCE_PERIODIC_INSPECTION: CarbonMonoxideMaintenance
CARBON_MONOXIDE_MAINTENANCE_UNSPECIFIED: CarbonMonoxideMaintenance
CARBON_MONOXIDE_REPLACEMENT_EOL: CarbonMonoxideReplacement
CARBON_MONOXIDE_REPLACEMENT_UNSPECIFIED: CarbonMonoxideReplacement
CARBON_MONOXIDE_STATE_CLEAR: CarbonMonoxideState
CARBON_MONOXIDE_STATE_DETECTED: CarbonMonoxideState
CARBON_MONOXIDE_STATE_MAINTENANCE_REQUIRED: CarbonMonoxideState
CARBON_MONOXIDE_STATE_REPLACEMENT_REQUIRED: CarbonMonoxideState
CARBON_MONOXIDE_STATE_SILENCED: CarbonMonoxideState
CARBON_MONOXIDE_STATE_TEST: CarbonMonoxideState
CARBON_MONOXIDE_STATE_UNSPECIFIED: CarbonMonoxideState
DESCRIPTOR: _descriptor.FileDescriptor

class CarbonMonoxideGetRequest(_message.Message):
    __slots__ = ["metadata"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.DeviceMetadata
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ...) -> None: ...

class CarbonMonoxideGetResponse(_message.Message):
    __slots__ = ["unit", "value"]
    UNIT_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    unit: _units_pb2.Unit
    value: float
    def __init__(self, unit: _Optional[_Union[_units_pb2.Unit, str]] = ..., value: _Optional[float] = ...) -> None: ...

class CarbonMonoxideStateReport(_message.Message):
    __slots__ = ["maintenance", "replacement", "state"]
    MAINTENANCE_FIELD_NUMBER: _ClassVar[int]
    REPLACEMENT_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    maintenance: CarbonMonoxideMaintenance
    replacement: CarbonMonoxideReplacement
    state: CarbonMonoxideState
    def __init__(self, state: _Optional[_Union[CarbonMonoxideState, str]] = ..., replacement: _Optional[_Union[CarbonMonoxideReplacement, str]] = ..., maintenance: _Optional[_Union[CarbonMonoxideMaintenance, str]] = ...) -> None: ...

class CarbonMonoxideValueReport(_message.Message):
    __slots__ = ["unit", "value"]
    UNIT_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    unit: _units_pb2.Unit
    value: float
    def __init__(self, unit: _Optional[_Union[_units_pb2.Unit, str]] = ..., value: _Optional[float] = ...) -> None: ...

class CarbonMonoxideState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class CarbonMonoxideReplacement(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class CarbonMonoxideMaintenance(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/battery.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bvemmio_client/battery.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\"?\n\x11\x42\x61tteryGetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"#\n\x12\x42\x61tteryGetResponse\x12\r\n\x05level\x18\x01 \x01(\x05\"\x1e\n\rBatteryReport\x12\r\n\x05level\x18\x01 \x01(\x05\x32R\n\x07\x42\x61ttery\x12G\n\nBatteryGet\x12\x1b.vemmiopb.BatteryGetRequest\x1a\x1c.vemmiopb.BatteryGetResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.battery_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _BATTERYGETREQUEST._serialized_start=71
  _BATTERYGETREQUEST._serialized_end=134
  _BATTERYGETRESPONSE._serialized_start=136
  _BATTERYGETRESPONSE._serialized_end=171
  _BATTERYREPORT._serialized_start=173
  _BATTERYREPORT._serialized_end=203
  _BATTERY._serialized_start=205
  _BATTERY._serialized_end=287
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WiFiBSS(_message.Message):
    __slots__ = ["frequency", "last_seen", "ssid"]
    FREQUENCY_FIELD_NUMBER: _ClassVar[int]
    LAST_SEEN_FIELD_NUMBER: _ClassVar[int]
    SSID_FIELD_NUMBER: _ClassVar[int]
    frequency: int
    last_seen: int
    ssid: str
    def __init__(self, ssid: _Optional[str] = ..., frequency: _Optional[int] = ..., last_seen: _Optional[int] = ...) -> None: ...

class WiFiConnectRequest(_message.Message):
    __slots__ = ["psk", "ssid"]
    PSK_FIELD_NUMBER: _ClassVar[int]
    SSID_FIELD_NUMBER: _ClassVar[int]
    psk: str
    ssid: str
    def __init__(self, ssid: _Optional[str] = ..., psk: _Optional[str] = ...) -> None: ...

class WiFiConnectResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class WiFiInterface(_message.Message):
    __slots__ = ["bss", "hardware_addr", "name", "stations"]
    BSS_FIELD_NUMBER: _ClassVar[int]
    HARDWARE_ADDR_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    STATIONS_FIELD_NUMBER: _ClassVar[int]
    bss: WiFiBSS
    hardware_addr: bytes
    name: str
    stations: _containers.RepeatedCompositeFieldContainer[WiFiStation]
    def __init__(self, name: _Optional[str] = ..., hardware_addr: _Optional[bytes] = ..., bss: _Optional[_Union[WiFiBSS, _Mapping]] = ..., stations: _Optional[_Iterable[_Union[WiFiStation, _Mapping]]] = ...) -> None: ...

class WiFiQueryRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class WiFiQueryResponse(_message.Message):
    __slots__ = ["interfaces", "timestamp"]
    INTERFACES_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    interfaces: _containers.RepeatedCompositeFieldContainer[WiFiInterface]
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, interfaces: _Optional[_Iterable[_Union[WiFiInterface, _Mapping]]] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class WiFiScanRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class WiFiScanResponse(_message.Message):
    __slots__ = ["bsss"]
    BSSS_FIELD_NUMBER: _ClassVar[int]
    bsss: _containers.RepeatedCompositeFieldContainer[WiFiBSS]
    def __init__(self, bsss: _Optional[_Iterable[_Union[WiFiBSS, _Mapping]]] = ...) -> None: ...

class WiFiStation(_message.Message):
    __slots__ = ["connected", "hardware_addr", "inactive", "signal"]
    CONNECTED_FIELD_NUMBER: _ClassVar[int]
    HARDWARE_ADDR_FIELD_NUMBER: _ClassVar[int]
    INACTIVE_FIELD_NUMBER: _ClassVar[int]
    SIGNAL_FIELD_NUMBER: _ClassVar[int]
    connected: int
    hardware_addr: bytes
    inactive: int
    signal: int
    def __init__(self, hardware_addr: _Optional[bytes] = ..., signal: _Optional[int] = ..., connected: _Optional[int] = ..., inactive: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/addon.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vemmio_client/addon.proto\x12\x08vemmiopb\"\x12\n\x10\x41\x64\x64onListRequest\"\x97\x01\n\x11\x41\x64\x64onListResponse\x12\x31\n\x06\x61\x64\x64ons\x18\x01 \x03(\x0b\x32!.vemmiopb.AddonListResponse.Addon\x1aO\n\x05\x41\x64\x64on\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12/\n\nthermostat\x18\x02 \x01(\x0b\x32\x19.vemmiopb.AddonThermostatH\x00\x42\x07\n\x05\x61\x64\x64on\"J\n\x19\x41\x64\x64onAddThermostatRequest\x12-\n\nthermostat\x18\x01 \x01(\x0b\x32\x19.vemmiopb.AddonThermostat\" \n\x10\x41\x64\x64onAddResponse\x12\x0c\n\x04uuid\x18\x01 \x01(\t\"B\n\x0f\x41\x64\x64onThermostat\x12\x16\n\x0einput_filename\x18\x01 \x01(\t\x12\x17\n\x0foutput_filename\x18\x02 \x01(\t2\xa4\x01\n\x05\x41\x64\x64on\x12\x44\n\tAddonList\x12\x1a.vemmiopb.AddonListRequest\x1a\x1b.vemmiopb.AddonListResponse\x12U\n\x12\x41\x64\x64onAddThermostat\x12#.vemmiopb.AddonAddThermostatRequest\x1a\x1a.vemmiopb.AddonAddResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.addon_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _ADDONLISTREQUEST._serialized_start=39
  _ADDONLISTREQUEST._serialized_end=57
  _ADDONLISTRESPONSE._serialized_start=60
  _ADDONLISTRESPONSE._serialized_end=211
  _ADDONLISTRESPONSE_ADDON._serialized_start=132
  _ADDONLISTRESPONSE_ADDON._serialized_end=211
  _ADDONADDTHERMOSTATREQUEST._serialized_start=213
  _ADDONADDTHERMOSTATREQUEST._serialized_end=287
  _ADDONADDRESPONSE._serialized_start=289
  _ADDONADDRESPONSE._serialized_end=321
  _ADDONTHERMOSTAT._serialized_start=323
  _ADDONTHERMOSTAT._serialized_end=389
  _ADDON._serialized_start=392
  _ADDON._serialized_end=556
# @@protoc_insertion_point(module_scope)
